@@ -33,7 +33,9 @@ proc LoadStateList {} {
 # Saves the list of states to the file in the HOME dir
 proc SaveStateList {} {
 	global HOME tcl_platform 
-    
+    if {![file exists [file join ${HOME} states.xml]]} {
+    	return
+    }
 	if {$tcl_platform(platform) == "unix"} {
 		set file_id [open "[file join ${HOME} states.xml]" w 00600]
 	} else {
@@ -133,7 +135,7 @@ proc CreateStatesMenu { path } {
 		menu $path.editstates -tearoff 0 -type normal
 		menu $path.deletestates -tearoff 0 -type normal
 	}
-#	if { [::config::getKey dock] != 0 && [winfo exists $iconmenu] && [$iconmenu index end] != 16} {
+#	if { [::config::getKey docking] && [winfo exists $iconmenu] && [$iconmenu index end] != 16} {
 #		$iconmenu delete 17 end
 #	}
     
@@ -148,7 +150,7 @@ proc CreateStatesMenu { path } {
 		$path.deletestates add command -label "[lindex [StateList get $idx] 0]" -command "DeleteState $idx $path"
 		$path.editstates add command -label "[lindex [StateList get $idx] 0]" -command "EditNewState 2 $idx"
 		$path add command -label "[lindex [StateList get $idx] 0]" -command "ChCustomState $idx"
-#		if { [::config::getKey dock] != 0 && [winfo exists $iconmenu] } {
+#		if { [::config::getKey docking]  && [winfo exists $iconmenu] } {
 #			$iconmenu add command -label "   [lindex [StateList get $idx] 0]" -command "ChCustomState $idx" -state disabled
 #		}
 	}
@@ -160,20 +162,20 @@ proc CreateStatesMenu { path } {
 		} else {
 			$path.otherstates delete 0 end
 		}
-#		if { [::config::getKey dock] != 0 && [winfo exists $iconmenu] && ![winfo exists $iconmenu.otherstates] } {
+#		if { [::config::getKey docking] && [winfo exists $iconmenu] && ![winfo exists $iconmenu.otherstates] } {
 #			menu $iconmenu.otherstates -tearoff 0 -type normal
-#		} elseif { [::config::getKey dock] != 0 && [winfo exists $iconmenu.otherstates] } {
+#		} elseif { [::config::getKey docking] && [winfo exists $iconmenu.otherstates] } {
 #			$iconmenu.otherstates delete 0 end
 #		}
 		for {} { $idx <= [expr {[StateList size] - 1}] } { incr idx } {
 			$path.deletestates add command -label "[lindex [StateList get $idx] 0]" -command "DeleteState $idx $path"
 			$path.editstates add command -label "[lindex [StateList get $idx] 0]" -command "EditNewState 2 $idx"
 			$path.otherstates add command -label "[lindex [StateList get $idx] 0]" -command "ChCustomState $idx"
-#			if { [::config::getKey dock] != 0 && [winfo exists $iconmenu] } {
+#			if { [::config::getKey docking] && [winfo exists $iconmenu] } {
 #				$iconmenu.otherstates add command -label "[lindex [StateList get $idx] 0]" -command "ChCustomState $idx"
 #			}
 		}
-#		if { [::config::getKey dock] != 0 && [winfo exists $iconmenu.otherstates] } {
+#		if { [::config::getKey docking] && [winfo exists $iconmenu.otherstates] } {
 #			$iconmenu add cascade -label "   [trans morepersonal]" -menu $iconmenu.otherstates -state disabled
 #			$iconmenu add separator
 #			$iconmenu add command -label "[trans close]" -command "close_cleanup;exit"
@@ -190,25 +192,23 @@ proc CreateStatesMenu { path } {
 			$path add cascade -label "[trans editcustomstate]" -menu $path.editstates
 			$path add cascade -label "[trans deletecustomstate]" -menu $path.deletestates
 		}
-#		if { [::config::getKey dock] != 0 && [winfo exists $iconmenu] } {
+#		if { [::config::getKey docking] && [winfo exists $iconmenu] } {
 #			$iconmenu add separator
 #			$iconmenu add command -label "[trans close]" -command "close_cleanup;exit"
 #		}
 	}
 	$path add separator
 	$path add command -label "[trans changenick]..." -command cmsn_change_name
-	if { [::config::getKey getdisppic] == 1 } {
-		$path add command -label "[trans changedisplaypic]..." -command pictureBrowser 
-	} else {
-		$path add command -label "[trans changedisplaypic]..." -command pictureBrowser -state disabled
-	}
+	
+	$path add command -label "[trans changedisplaypic]..." -command pictureBrowser 
+
 	$path add command -label "[trans cfgalarmall]..." -command "::alarms::configDialog all"
 #	statusicon_proc [MSN::myStatusIs]
 
-	if { [::config::getKey dock] != 0 && [winfo exists $iconmenu.imstatus] && $path != "$iconmenu.imstatus" } {
+	if { [::config::getKey use_dock] && [winfo exists $iconmenu.imstatus] && $path != "$iconmenu.imstatus" } {
 		CreateStatesMenu $iconmenu.imstatus
 	}
-	if { [::config::getKey dock] != 0 && [winfo exists $iconmenu.imstatus] && $path == "$iconmenu.imstatus" } {
+	if { [::config::getKey use_dock] && [winfo exists $iconmenu.imstatus] && $path == "$iconmenu.imstatus" } {
 		$path delete [expr "[$path index end] - 3"] end
 	}
 }
@@ -225,7 +225,7 @@ proc ChCustomState { idx } {
 	if { [string is digit $idx] == 1 } {
 		if { [lindex [StateList get $idx] 2] != "" } {
 			if {![info exists original_nick] && [::config::getKey storename]} {
-				set original_nick [::abook::getPersonal nick]
+				set original_nick [::abook::getPersonal MFN]
 			}
 			#set new_state [lindex [lindex $list_states [lindex [StateList get $idx] 2]] 0]
 			set new_state [::MSN::numberToState [lindex [StateList get $idx] 2]]
@@ -243,10 +243,12 @@ proc ChCustomState { idx } {
 						puts $nickcache [::abook::getPersonal login]
 						close $nickcache
 					}
+				set newname [string map { "\\" "\\\\" "\$" "\\\$" } $newname]
+				set newname [string map { "\\\$nick" "\${original_nick}" } $newname]
+				set newname [subst -nocommands $newname]
 				::MSN::changeName [::config::getKey login] $newname
 				StateList promote $idx
 			}
-			::MSN::changeStatus $new_state
 		}
 	} else {
 		set automessage "-1"
@@ -258,8 +260,21 @@ proc ChCustomState { idx } {
 			unset original_nick
 			catch { file delete [file join ${HOME} "nick.cache"] }
 		}
-		::MSN::changeStatus $idx
+		set new_state $idx
 	}
+
+	if { [info exists new_state] } {
+		::MSN::changeStatus $new_state
+
+		#PostEvent 'ChangeMyState' when the user changes his/her state
+		set evPar(automessage) $automessage
+		set evPar(idx) $new_state
+		::plugins::PostEvent ChangeMyState evPar
+	} else {
+		status_log "ChCustomState where state didnt exist !!!" red
+	}
+
+
 	CreateStatesMenu .my_menu
 	if { [info exists automsgsent] } {
 		unset automsgsent
@@ -294,7 +309,7 @@ proc EditNewState { mode { idx "" } } {
 		return 0
 	}
 
-	::skin::setPixmap prefaway [file join [GetSkinFile pixmaps prefaway.gif]]
+	::skin::setPixmap prefaway [file join [::skin::GetSkinFile pixmaps prefaway.gif]]
 
 	toplevel .editstate
 	#wm group .editstate .
@@ -322,9 +337,15 @@ proc EditNewState { mode { idx "" } } {
 	pack .editstate.1.laway -fill both -side left
     
 	label $lfname.ldesc -text "[trans statename] :" -font splainf 
-	entry $lfname.edesc -bg #FFFFFF -bd 1 -font splainf -highlightthickness 0 -width 40
+	entry $lfname.edesc -bg #FFFFFF -font splainf -width 40
 	label $lfname.lnick -text "[trans statenick] :" -font splainf
-	entry $lfname.enick -bg #FFFFFF -bd 1 -font splainf -highlightthickness 0 -width 40
+	entry $lfname.enick -bg #FFFFFF -font splainf  -width 40
+	menubutton $lfname.nickhelp -font sboldf -text "<-" -menu $lfname.nickhelp.menu
+	menu $lfname.nickhelp.menu -tearoff 0
+	$lfname.nickhelp.menu add command -label [trans nick] -command "$lfname.enick insert insert \\\$nick"
+	$lfname.nickhelp.menu add separator
+	$lfname.nickhelp.menu add command -label [trans delete] -command "$lfname.enick delete 0 end"
+	
 	label $lfname.lstate -text "[trans state] :" -font splainf
 	combobox::combobox $lfname.statebox -editable false -highlightthickness 0 -width 37 -bg #FFFFFF -font splainf -command ""
 	label $lfname.lmsg -text "[trans stateautomsg] :" -font splainf
@@ -335,6 +356,7 @@ proc EditNewState { mode { idx "" } } {
 	grid $lfname.edesc -row 1 -column 2 -sticky w -pady 5 -padx 5
 	grid $lfname.lnick -row 2 -column 1 -sticky w -pady 5 -padx 5
 	grid $lfname.enick -row 2 -column 2 -sticky w -pady 5 -padx 5
+	grid $lfname.nickhelp -row 2 -column 3 -sticky w -pady 5 -padx 5
 	grid $lfname.lstate -row 3 -column 1 -sticky w -pady 5 -padx 5
 	grid $lfname.statebox -row 3 -column 2 -sticky w -pady 5 -padx 5
 	grid $lfname.lmsg -row 4 -column 1 -sticky nw -pady 10 -padx 5
@@ -382,9 +404,9 @@ proc EditNewState { mode { idx "" } } {
 		$lfname.emsg insert end [lindex [StateList get $idx] 4]
 	}
 	#else {
-	#	$lfname.enick insert end [::abook::getPersonal nick]
+	#	$lfname.enick insert end [::abook::getPersonal MFN]
 	#}
-	button .editstate.buttons.save -text [trans ok] -command "ButtonSaveState $lfname $idx; destroy .editstate"
+	button .editstate.buttons.save -text [trans ok] -command "ButtonSaveState $lfname $idx; destroy .editstate" -default active
 	pack .editstate.buttons.save .editstate.buttons.cancel -side right -padx 10 -pady 5
 	pack .editstate.buttons -side top -fill x -pady 10
 	moveinscreen .editstate
@@ -416,29 +438,24 @@ proc ButtonSaveState { lfname { idx "" } } {
 			if { $chstate == 1 } {
 				ChCustomState [expr {[StateList size] - 1}]
 			}
-			}
+		}
 		1 {
 			StateList add $gui_info
 			ChCustomState [expr {[StateList size] - 1}]
-			StateList unset 0
-			}
+			StateList unset [expr {[StateList size] - 1}]
+		}
 		2 {
 			StateList edit $gui_info $idx
 			if { $chstate == 1 } {
 				ChCustomState $idx
 			}
-			}
+		}
 	}    
 
 	# reset menus and listbox
 	CreateStatesMenu .my_menu
 	if { ($mode == 0 || $mode == 2) && [winfo exists .cfg] } {
-	#REMOVE THAT WHEN MAC OS X WILL MOVE TO BWIDGET IN PREFERENCES
-		if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
-		set cfgname [Rnotebook:frame .cfg.notebook.nn 3]
-		} else {
 		set cfgname [[.cfg.notebook.nn getframe session].sw.sf getframe]
-		}
 		$cfgname.lfname2.f.f.statelist.box delete 0 end
 		for { set idx 0 } { $idx < [StateList size] } {incr idx } {
 			$cfgname.lfname2.f.f.statelist.box insert end [lindex [StateList get $idx] 0]
