@@ -1,5 +1,5 @@
 ##############################################################################
-# $Id: balloon.tcl,v 1.26 2004/08/20 12:09:27 yozko Exp $
+# $Id: balloon.tcl,v 1.36 2005/06/18 18:51:09 germinator2000 Exp $
 #
 # balloon.tcl - procedures used by balloon help
 #
@@ -29,7 +29,7 @@ bind Bulle <Enter> {
     set Bulle(set) 0
     set Bulle(first) 1
     set win %W 
-    set Bulle(id) [after 1000 [list balloon ${win} $Bulle(${win}) %X %Y]]
+    set Bulle(id) [after 1000 [list balloon ${win} $Bulle(${win}) $BullePic(${win}) %X %Y]]
 }
 
 bind Bulle <Button> {
@@ -46,20 +46,24 @@ bind Bulle <Motion> {
     if {$Bulle(set) == 0} {
         after cancel $Bulle(id)
 	set win %W
-        set Bulle(id) [after 1000 [list balloon ${win} $Bulle(${win}) %X %Y]]
+        set Bulle(id) [after 1000 [list balloon ${win} $Bulle(${win}) $BullePic(${win}) %X %Y]]
     }
 }
 
-proc set_balloon {target message} {
+proc set_balloon {target message {pic ""}} {
     global Bulle
+    global BullePic
     set Bulle(${target}) ${message}
+    set BullePic(${target}) ${pic}
     bindtags ${target} "[bindtags ${target}] Bulle"
 }
 
-proc change_balloon {target message} {
+proc change_balloon {target message {pic ""}} {
 	kill_balloon
 	global Bulle
+    global BullePic
     set Bulle(${target}) ${message}
+    set BullePic(${target}) ${pic}
 }
 
 proc kill_balloon {} {
@@ -73,14 +77,27 @@ proc kill_balloon {} {
     }
 }
 
-proc balloon {target message {cx 0} {cy 0} } {
+proc balloon {target message pic {cx 0} {cy 0} } {
     global Bulle tcl_platform
+    #check that the mouse is over the target (fix a tk bug - in windows)
+    if {[eval winfo containing  [winfo pointerxy .]]!=$target} {
+    	set Bulle(first) 0
+    	kill_balloon
+   	return
+    }
+    
     #Last focus variable for "Mac OS X focus bug" with balloon
     set lastfocus [focus]
     
     after cancel "kill_balloon"
     if {$Bulle(first) == 1 } {
         set Bulle(first) 2
+	
+	if { [string equal -length 11 $message "--command--"] } {
+		set command [string range $message 11 end]
+		set message [eval $command]
+	}
+	
 	if { $cx == 0 && $cy == 0 } {
 	    set x [expr [winfo rootx ${target}] + ([winfo width ${target}]/2)]
 	    set y [expr [winfo rooty ${target}] + [winfo height ${target}] + 2]
@@ -89,9 +106,9 @@ proc balloon {target message {cx 0} {cy 0} } {
 	    set y [expr $cy + 2]
 	}
 	
-	if { [catch { toplevel .balloon -bg [::skin::getColor balloonborder]}] != 0 } {
+	if { [catch { toplevel .balloon -bg [::skin::getKey balloonborder]}] != 0 } {
 		destroy .balloon
-		toplevel .balloon -bg [::skin::getColor balloonborder]
+		toplevel .balloon -bg [::skin::getKey balloonborder]
 	}
 	
 	#Standard way to show balloon on Mac OS X (aqua), show balloon in white for Mac OS X and skinnable balloons for others platforms
@@ -103,20 +120,41 @@ proc balloon {target message {cx 0} {cy 0} } {
 	} else {
 		wm overrideredirect .balloon 1
 	}
+
+	frame .balloon.f -bg [::skin::getKey balloonbackground]
+	pack .balloon.f
+	if { $pic != "" && ![catch {$pic cget -file}]} {
+		label .balloon.f.pic -image $pic -bg [::skin::getKey balloonbackground]
+		pack .balloon.f.pic -side left -padx 2 -pady 2
+		set iwidth [image width $pic]
+	} else {
+		set iwidth 0
+	}
+
 	
-	set wlength [expr {[winfo screenwidth .] - $x - 5}]
+	set wlength [expr {[winfo screenwidth .] - $x - 15 - $iwidth }]
 	#If available width is less than 200 pixels, make the balloon
 	#200 pixels width, and move it to the left so it's inside the screen
 	if { $wlength < 200 } {
-	    set offset [expr {$wlength - 200}]
-	    incr x $offset
-	    set wlength 200
+	    #set offset [expr {$wlength - 200 - [image width $pic] - 10}]
+	    #incr x $offset
+		set x [expr { [winfo screenwidth . ] - 200 - 15 - $iwidth } ]
+		set wlength 200
 	}
 
-        label .balloon.l \
+        label .balloon.f.l \
 	    -text ${message} -relief flat \
-	    -bg [::skin::getColor balloonbackground] -fg [::skin::getColor balloontext] -padx 2 -pady 0 -anchor w -font sboldf -justify left -wraplength $wlength
-	pack .balloon.l -side left -padx 1 -pady 1
+	    -bg [::skin::getKey balloonbackground] -fg [::skin::getKey balloontext] -padx 2 -pady 0 -anchor w -font [::skin::getKey balloonfont] -justify left -wraplength $wlength
+	if {$tcl_platform(platform) == "windows"} {
+		set bw [expr [::skin::getKey balloonborderwidth]]
+	} else {
+		set bw [expr [::skin::getKey balloonborderwidth] - 1 ]
+		if {$bw < 0} {
+			set bw 0
+		}
+	}
+	
+	pack .balloon.f.l -side left -padx $bw -pady $bw
         wm geometry .balloon +${x}+${y}
         
 	#Focus last windows , in AquaTK ("Mac OS X focus bug")
