@@ -1,18 +1,18 @@
 #
-# $Id: config.tcl,v 1.260 2004/11/06 14:13:03 airadier Exp $
+# $Id: config.tcl,v 1.305 2005/11/20 19:19:53 germinator2000 Exp $
 #
 
 namespace eval ::config {
 
 	proc configDefaults {} {
 		global tcl_platform password auto_path advanced_options
-	
+
 		::config::setKey protocol "9"		;# Which MSN Protocol do you prefer to use: 9
 		::config::setKey nossl 0			;#Disable the use of SSL, so it doesn't requite TLS package: 0|1
-	
+
 		::config::setKey login ""			;# These are defaults for users without
 		::config::setKey save_password 0		;# a config file: 0|1
-	
+
 		::config::setKey keep_logs 1			;#Save log files: 0|1
 		::config::setKey display_event_connect 1	;#Display when someone connect
 		::config::setKey display_event_disconnect 1	;#Display when someone disconnect
@@ -22,38 +22,34 @@ namespace eval ::config {
 		::config::setKey log_event_disconnect 0	;#Log when someone disconnect
 		::config::setKey log_event_email 0		;#Log when a new E-Mail is received
 		::config::setKey log_event_state 0		;#Log changement of status
-	
+
 		::config::setKey connectiontype direct	;# Connection type: direct|http|proxy
 		::config::setKey proxy ""			;# If using proxy, proxy host
 		::config::setKey proxytype "http"		;# Proxy type: http|ssl|socks5
 		::config::setKey proxyauthenticate 0		;# SOCKS5 use username/password
 		::config::setKey proxyuser ""		;# user and password for SOCKS5 proxy
 		::config::setKey proxypass ""		;#
-	
+
 		::config::setKey sound 1			;#Sound enabled: 0|1
 		::config::setKey mailcommand ""		;#Command for checking mail. Blank for hotmail
 		::config::setKey notifytyping 1		;#Send typing notifications
 		::config::setKey soundactive 0               ;#Typing sound even on active window
-		
+
 		::config::setKey chatstyle	"msn"		;#Chat display style
-	
+
 		::config::setKey reconnect 1			;#Variable for amsn to reconnect on loss
-	
-		::config::setKey dock 0				;#Docking type
+
+		::config::setKey dock 1				;#Docking type
 								;#Changed later for windows to 4
-	
+
 		#Some Autodetected options
 		if {$tcl_platform(os) == "Darwin"} {
-			set osversion [string range "$tcl_platform(osVersion)" 0 0]
-			if { $osversion == "6"} {
-				::config::setKey soundcommand "utils/qtplay \$sound";#Soundplayer for Mac OS 10.2 Jaguar
-			} else {
-				::config::setKey soundcommand "./sndplay \$sound";#Soundplayer for Mac OS 10.3 Panther
-			}
+			::config::setKey soundcommand "./sndplay \$sound";#Soundplayer for Mac OS 10.3-10.4	
 			::config::setKey browser "open \$url"
 			::config::setKey notifyXoffset 100
 			::config::setKey notifyYoffset 75
-			::config::setKey filemanager "open \$location"   
+			::config::setKey filemanager "open \$location"
+			::config::setKey openfilecommand "open \$file"
 			::config::setKey usesnack 0
 		} elseif {$tcl_platform(platform) == "unix"} {
 			::config::setKey soundcommand "play \$sound"
@@ -61,45 +57,47 @@ namespace eval ::config {
 			::config::setKey notifyXoffset 0
 			::config::setKey notifyYoffset 0
 			::config::setKey filemanager "my_filemanager open \$location"
+			::config::setKey openfilecommand ""
 			::config::setKey usesnack 0
 		} elseif {$tcl_platform(platform) == "windows"} {
-			::config::setKey soundcommand "utils/plwav.exe \$sound"
+			::config::setKey soundcommand "utils/windows/plwav.exe \$sound"
 			::config::setKey browser "explorer \$url"
 			::config::setKey notifyXoffset 0
 			::config::setKey notifyYoffset 28
 			::config::setKey filemanager "explorer \$location"
+			::config::setKey openfilecommand "start \$file"
 			::config::setKey usesnack 1
-			::config::setKey dock 4				;#Set docking to type 4 (windows)
+			#::config::setKey dock 4				;#Set docking to type 4 (windows)
 		} else {
 			::config::setKey soundcommand ""			;#Sound player command
 			::config::setKey browser ""			;#Browser command
 			::config::setKey filemanager ""			;#Filemanager command
-		
+			::config::setKey openfilecommand ""
 			::config::setKey notifyXoffset 0			;#Notify window offsets
 			::config::setKey notifyYoffset 0
 			::config::setKey usesnack 0			;#Use the Snack library for sounds
 		}
-		
+
 		::config::setKey autoidle 1				;#Enable/disable auto-idle feature: 0|1
 		::config::setKey idletime 5				;#Minutes before setting status to idle
 		::config::setKey autoaway 1				;#Enable/disable auto-away feature: 0|1
 		::config::setKey awaytime 10				;#Minutes before setting status to away
-	
+
 		::config::setKey orderbygroup 0			;#Order contacts by group: 0=No | 1=Groups | 2=Hybrid
 		::config::setKey ordergroupsbynormal 1		;#Order groups normal or inverted
-	
+
 		::config::setKey dateformat MDY			;#Change date format (eg Month/Day/Year)
-	
+
 		::config::setKey listsmileys 1			;#Show smileys in contact list
 		::config::setKey chatsmileys 1			;#Show smileys in chat window
-	
+
 		::config::setKey startoffline 0			;#Start session as offline (hidden)
-	
+
 		::config::setKey autoftip 1				;#Detect IP for file transfers automatically
 		::config::setKey myip "127.0.0.1"			;#Your IP
 		::config::setKey manualip "127.0.0.1"		;#Manual IP
-	
-		
+
+
 		#Specific configs for Mac OS X (Aqua) first, and for others systems after
 		if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
 			::config::setKey wingeometry 275x400-200+200		;#Main window geometry on Mac OS X
@@ -109,23 +107,25 @@ namespace eval ::config {
 			::config::setKey wingeometry 275x400-0+0			;#Main window geometry
 			::config::setKey backgroundcolor  #D8D8E0		;#AMSN background color
 		}
-		
+
 		::config::setKey closingdocks 0						;#Close button minimizes (or docks) main window
 
 		::config::setKey encoding auto						;#ANSN encoding
-	
+
 		::config::setKey textsize 2							;#User text size
 		::config::setKey mychatfont "{Helvetica} {} 000000"	;#User chat font
 		::config::setKey winchatsize "350x320"		;#Default chat window size
+		::config::setKey winchatoutheight "200"		;#Default chat window output height
 		::config::setKey savechatwinsize 1			;#Save chat window sizes when changed?
-	
+		
+		::config::setKey notifyonlysound 0			;#Only play sound for notification : no notify window
 		::config::setKey notifymsg 1				;#Show notify window when a message arrives
 		::config::setKey notifyonline 1			;#Show notify window when a user goes online
 		::config::setKey notifyoffline 0			;#Show notify window when a user goes offline
 		::config::setKey notifystate 0			;#Show notify window when a user changes status
 		::config::setKey notifyemail 1			;#Show notify window when a new mail arrives
 		::config::setKey notifyemailother 0			;#Show notify window when a new mail arrives in other folders
-	
+
 		#Specific for Mac OS X, if newchatwinstate=1, new windows of message never appear
 		if {$tcl_platform(os) == "Darwin"} {
 			::config::setKey newchatwinstate 0		;#Iconify or restore chat window on new chat
@@ -134,22 +134,24 @@ namespace eval ::config {
 			::config::setKey newchatwinstate 1		;#Iconify or restore chat window on new chat
 			::config::setKey newmsgwinstate 1		;#Iconify or restore chat window on new message
 		}
-		
+
 		::config::setKey flicker 1				;#Flicker window on new message
 		::config::setKey showdisplaypic 1		;#Show display picture as default
+		::config::setKey lazypicretrieval 0		;#Retrieve display pics in a lazy way, only when chatting to that user
 
 		::config::setKey autochangenick 1		;# automaticly change nick to custom state
-	
+
 		::config::setKey initialftport 6891	;#Initial for to be used when sending file transfers
 		::config::setKey ftautoaccept 0		;#Auto-Accept file transfer request (Off by default)
-		::config::setKey new_ft_protocol 0	;#Use new FileTransfer protocol (Off by default)
-	
+		::config::setKey ftautoclose 0		;#Auto-close file transfer windows when finished
+		::config::setKey disable_new_ft_protocol 0	;#Use new FileTransfer protocol (Off by default)
+
 		::config::setKey shownotify 1 			;#Show notify window (in general, see advanced options)
 		::config::setKey clientcaps 1			;#Send x-clientcaps information to others 3rd Messenger
 		#Remote control options
 		::config::setKey enableremote 0
 		::config::setKey remotepassword ""
-	
+
 		#Blocking detection options
 		::config::setKey checkonfln 0
 		::config::setKey checkblocking 0
@@ -158,26 +160,22 @@ namespace eval ::config {
 		::config::setKey blockinter3 5
 		::config::setKey blockusers 2
 		::config::setKey showblockedgroup 0
-	
+
 		::config::setKey emotisounds 1			;#Play sound on certain emoticons
 		::config::setKey animatedsmileys 1		;#Show animated smileys
-	
+
 		#Custom smileys configuration
-		::config::setKey customsmileys [list]
 		::config::setKey custom_smileys 1
 		::config::setKey logsbydate 1
 		::config::setKey p4c_name ""
-		
-		if {$tcl_platform(os) != "Darwin"} {
-		::config::setKey convertpath "convert"								;#Path for convert (from imagemagick)
-		} else {
-		::config::setKey convertpath "/usr/local/bin/convert"		;#Path for convert (from imagemagick) on Mac OS X
-		}
-	
+		::config::setKey tabbedchat 2
+		::config::setKey ContainerCloseAction 0
+		::config::setKey showMobileGroup 1
+
 		#Advanced options, not in preferences window
 		# Create the entry in the list and then, set
 		# the variable at bottom
-		
+
 		#List like:
 		#	"" trans_section_name_1
 		#  optionname1 type1 trans_name1 trans_desc1(optional)
@@ -204,6 +202,8 @@ namespace eval ::config {
 			[list local sngdblclick bool sngdblclick] \
 			[list local nogap bool nogap] \
 			[list local removeempty bool removeempty] \
+			[list local tabtitlenick bool tabtitlenick] \
+			[list local showpicnotify bool showpicnotify] \
 			[list title notifyoffset] \
 			[list local notifyXoffset int xoffset] \
 			[list local notifyYoffset int yoffset] \
@@ -222,12 +222,15 @@ namespace eval ::config {
 			[list local checkemail bool checkemail] \
 			[list local autoconnect bool autoconnect autoconnect2] \
 			[list local keepalive bool keepalive natkeepalive]\
-			[list local start_ns_server str notificationserver]\
-			[list local new_ft_protocol bool new_ft_protocol]\
+			[list local default_ns_server str notificationserver]\
+			[list local disable_new_ft_protocol bool_inv new_ft_protocol]\
+			[list local lazypicretrieval bool lazypicretrieval]\
 			[list title MSN] \
 			[list local displayp4context bool displayp4context] \
 			[list local p4contextprefix str p4contextprefix] \
 			[list title others] \
+			[list local activeautoupdate bool activeautoupdate] \
+			[list local updateonlycurrentlanguage bool updateonlycurrentlanguage] \
 			[list local allowbadwords bool allowbadwords] \
 			[list local libtls_temp folder TLS tlsexplain] \
 			[list local notifytyping bool notifytyping] \
@@ -251,7 +254,10 @@ namespace eval ::config {
 		::config::setKey showtimestamps 1		;#Show timestamps on messages ("Yes" by default)
 		::config::setKey leftdelimiter \[		;#Left Timestamps' delimiter  '[' by default
 		::config::setKey rightdelimiter \]		;#Right Timestamps' delimiter ']' by default
+		::config::setKey default_ns_server "messenger.hotmail.com:1863"
 		::config::setKey start_ns_server "messenger.hotmail.com:1863"
+		::config::setKey activeautoupdate 1		;#Active the auto update
+		::config::setKey updateonlycurrentlanguage 1	;#Only check updates for current language
 		::config::setKey allowbadwords 1		;#Disable censure on nicks
 		::config::setKey enablebanner 1		;#Show or Hide AMSN Banner (By default Show)
 		::config::setKey startontray 0		;#Start amsn on tray icon only (hide contact list)
@@ -260,6 +266,8 @@ namespace eval ::config {
 		::config::setKey sngdblclick 0		;#Use single or double click to open a message window (0 double, 1 single)
 		::config::setKey nogap 0			;#Remove the empty line between groups
 		::config::setKey removeempty 0		;#Remove empty groups from the contact list
+		::config::setKey tabtitlenick 1		;#Whether nick or mail is displayed in the tab
+		::config::setKey showpicnotify 1		;#Whether we show users pictures (if we have them) on the notify windows
 		::config::setKey emailsincontactlist 0	;#Display emails instead of nicks in the contact list
 		::config::setKey leavejoinsinchat	1	;#Display leave/join notifications in chat text area
 		::config::setKey charscounter	1	;#Display typed characters counter
@@ -270,29 +278,30 @@ namespace eval ::config {
 		::config::setKey notifytimeout 8000 ; #Number of milisecs before the notify will go away
 		::config::setKey globalnick ""		;#The global custom nickname (pattern), disabled by default
 		::config::setKey globaloverride 0		;# Sets whether Global nicknames pattern should override custom nicks, disabled by default
-	
+
 		#System options, not intended to be edited (unless you know what you're doing)
 		set password ""
 		::config::setKey withnotebook 0			;#Use notebook tabs in contact list
-	
+
 		::config::setKey adverts 0				;#Enable banner advertisements
 		::config::setKey displaypic "amsn.png"                   ;# Display picture
 		::config::setKey getdisppic 1
-		::config::setKey notifwidth 150			;#Notify window width
-		::config::setKey notifheight 100		;#Notify window height
+		::config::setKey webcamlogs 0
+		::config::setKey use_dock 1				;#enable/disable docking
+
 	}
-	
+
 	proc globalDefaults {} {
 		global gconfig tcl_platform
-		
-		setGlobalKey last_client_version ""		
+
+		setGlobalKey last_client_version ""
 		setGlobalKey language [detect_language "en"]	;#Default language
 		setGlobalKey skin "default"			;#AMSN skin
 		setGlobalKey disableprofiles 0 ;#Disable profiles (useful for cybercafes or similar)
 
 		#Specific configs for Mac OS X (Aqua) first, and for others systems after
 		if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
-			setGlobalKey basefont [list {Lucida Grande} 11 normal]	;#AMSN Mac OS X base font
+			setGlobalKey basefont [list {Lucida Grande} 12 normal]	;#AMSN Mac OS X base font
 		} elseif {$tcl_platform(platform) == "windows"} {
 			setGlobalKey basefont [list Arial 10 normal]
 		} else {
@@ -311,31 +320,31 @@ namespace eval ::config {
 			return $default
 		}
 	}
-	
+
 	proc getVar {key} {
 		return "::config($key)"
 	}
-	
+
 	proc getKeys {} {
 		return [array names ::config]
 	}
-	
+
 	proc getAll {} {
 		return [array get ::config]
 	}
-	
-			
+
+
 	proc setKey {key value} {
 		set ::config($key) $value
 	}
-	
+
 	proc setAll {values} {
 		array set ::config $values
 	}
-	
+
 	proc unsetKey {key} {
 		unset ::config($key)
-	}	
+	}
 
 	proc getGlobalKey {key {default ""}} {
 		if { [info exists ::gconfig($key)] } {
@@ -344,7 +353,7 @@ namespace eval ::config {
 			return $default
 		}
 	}
-	
+
 	proc getGlobalVar {key} {
 		return "::gconfig($key)"
 	}
@@ -356,7 +365,7 @@ namespace eval ::config {
 	proc getGlobalAll {} {
 		return [array get ::gconfig]
 	}
-	
+
 	proc setGlobalKey {key value} {
 		set ::gconfig($key) $value
 	}
@@ -380,7 +389,7 @@ namespace eval ::config {
 		global gconfig HOME2 HOME
 
 		globalDefaults
-		
+
 		if { [info exists HOME2] } {
 			set config_file [file join ${HOME2} "gconfig.xml"]
 		} else {
@@ -435,9 +444,9 @@ namespace eval ::config {
 
 proc save_config {} {
 	global tcl_platform HOME HOME2 version password custom_emotions
-	
+
 	status_log "save_config: saving config for user [::config::getKey login] in $HOME]\n" black
-	
+
 	if { [catch {
 		if {$tcl_platform(platform) == "unix"} {
 			set file_id [open "[file join ${HOME} config.xml]" w 00600]
@@ -460,18 +469,18 @@ proc save_config {} {
 
 	#Start of config file
 	puts $file_id  "<?xml version=\"1.0\"?>\n\n<config>"
-	
+
 	#Save all keys except special ones
 	foreach var_attribute [::config::getKeys] {
 		set var_value [::config::getKey $var_attribute]
-		if { "$var_attribute" != "remotepassword" && "$var_attribute" != "customsmileys"} {
+		if { "$var_attribute" != "remotepassword" } {
 			set var_value [::sxml::xmlreplace $var_value]
 			puts $file_id "   <entry>\n      <attribute>$var_attribute</attribute>\n      <value>$var_value</value>\n   </entry>"
 		}
 	}
 
 	#Save encripted password
-	if { ([::config::getKey save_password]) && ($password != "")} {	
+	if { ([::config::getKey save_password]) && ($password != "")} {
 		set key [string range "${loginback}dummykey" 0 7]
 		binary scan [::des::encrypt $key "${password}\n"] h* encpass
 		puts $file_id "   <entry>\n      <attribute>encpassword</attribute>\n      <value>$encpass</value>\n   </entry>"
@@ -483,7 +492,7 @@ proc save_config {} {
 	puts $file_id "   <entry>\n      <attribute>remotepassword</attribute>\n      <value>$encpass</value>\n   </entry>\n"
 
 	#Save custom emoticons
-	foreach name [::config::getKey customsmileys] {
+	foreach name [array names custom_emotions] {
 		puts $file_id "   <emoticon>"
 		array set emotion $custom_emotions($name)
 		foreach attribute [array names emotion] {
@@ -496,16 +505,16 @@ proc save_config {} {
 		puts $file_id "   </emoticon>\n"
 	}
 
-	#End of config file	
+	#End of config file
 	puts $file_id "</config>"
-	
+
 	close $file_id
-	
+
 	::config::setKey login $loginback
 	set password $passback
-	
+
 	status_log "save_config: Config saved\n" black
-    
+
 
 }
 
@@ -519,19 +528,19 @@ proc new_config_entry  {cstack cdata saved_data cattr saved_attr args} {
 }
 
 proc load_config {} {
-	global HOME password protocol clientid tcl_platform
+	global HOME password protocol tcl_platform
 
 	#Create custom smileys folder
 	create_dir "[file join ${HOME} smileys]"
 
 	set user_login [::config::getKey login]
 	status_log "load_config: Started. HOME=$HOME, config(login)=$user_login\n"
-	
+
 	#Set default values
 	::config::configDefaults
 
 	if { [file exists [file join ${HOME} "config.xml"]] } {
-	
+
 		status_log "load_config: loading file [file join ${HOME} config.xml]\n" blue
 
 		if { [catch {
@@ -543,15 +552,16 @@ proc load_config {} {
 			sxml::end $file_id
 			status_log "load_config: Config loaded\n" green
 			if { [winfo exists .smile_selector]} { destroy .smile_selector }
-			
+
 		} res] } {
 			::amsn::errorMsg "[trans corruptconfig [file join ${HOME} "config.xml.old"]]"
+			status_log "Error when parsing confog.xml : $res"
 			file copy -force [file join ${HOME} "config.xml"] [file join ${HOME} "config.xml.old"]
 			::sxml::end $file_id
 			::config::configDefaults
 			file delete [file join ${HOME} "config.xml"]
 		}
-		
+
 		#Force the change of the default background color and other specific Mac things
 		if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
 			set bgcolormac [::config::getKey backgroundcolor]
@@ -566,15 +576,23 @@ proc load_config {} {
 			# For Mac OS X users who used aMSN 0.90 at the beggining
 			set soundmac [string range "[::config::getKey soundcommand]" 1 11]
 				if { $soundmac=="program_dir" } {
-					set osversion [string range "$tcl_platform(osVersion)" 0 0]
-					if { $osversion == "6"} {
-						::config::setKey soundcommand "utils/qtplay \$sound"
-					} else {
 						::config::setKey soundcommand "./sndplay \$sound"
-					}
-				}			
+				}
 			}
 	}
+	#Force to change the path to the new path of plwav.exe
+	if {$tcl_platform(platform) == "windows"} {
+		if {[::config::getKey soundcommand] == "utils/plwav.exe \$sound"} {
+			::config::setKey soundcommand "utils/windows/plwav.exe \$sound"
+		}
+	}
+	#Sometimes, if there is a bugreport when opening a new window, the size of the window savez will be 1x1
+	if {[::config::getKey winchatsize]=="1x1"} {
+		::config::setKey winchatsize "350x320"
+	}
+	if {[::config::getKey wincontainersize]=="1x1"} {
+		::config::setKey wincontainersize "350x320"
+	}
 
 	#Get the encripted password
 	if {[::config::getKey encpassword]!=""} {
@@ -588,7 +606,7 @@ proc load_config {} {
 		::config::unsetKey encpassword
 	}
 
-	#Get the encripted remote password
+	#Get the encrypted remote password
 	if {[::config::getKey remotepassword]!=""} {
 		set key [string range "[::config::getKey login]dummykey" 0 7]
 		catch {set encpass [binary format h* [::config::getKey remotepassword]]}
@@ -598,10 +616,10 @@ proc load_config {} {
 		#puts "Password is: [::config::getKey remotepassword]\nHi\n"
 	}
 
-	#MSN 6.0 ClientID:
-	#set clientid "268435500"
-	#MSN 7.0 ClientID:
-	set clientid 1073741868
+	::config::setKey clientid 0
+	::MSN::setClientCap msnc4
+	::MSN::setClientCap inkgif
+	::MSN::setClientCap multip
 
 	# Load up the personal states
 	LoadStateList
@@ -610,17 +628,17 @@ proc load_config {} {
 		status_log "load_config: Empty login !!! FIXING\n" red
 		::config::setKey login $user_login
 	}
-    
+
 	if { [::config::getKey enableremote] } {
 		init_remote_DS
 	}
-    
+
 	#set the banner for this user when switching users
 	global initialize_amsn
 	if { $initialize_amsn != 1 } {
 		resetBanner
 	}
-    
+
 	#load Snack when being used
 	if { [::config::getKey usesnack] } {
 		if {![catch {package require snack}]} {
@@ -630,8 +648,8 @@ proc load_config {} {
 			save_config
 			#msg_box [trans snackfailed]
 		}
-	} 
-    
+	}
+
 	::plugins::LoadPlugins
 }
 
@@ -645,13 +663,13 @@ proc LoadLoginList {{trigger 0}} {
 
 	#puts stdout "called loadloginlist\n"
 	status_log "LoadLoginList: starting\n" blue
-	
+
 	if { $trigger != 0 } {
 		status_log "LoadLoginList: getting profiles\n" blue
 	} else {
 		set HOME2 $HOME
 	}
-		
+
 
 	if {([file readable "[file join ${HOME} profiles]"] != 0) && ([file isfile "[file join ${HOME} profiles]"] != 0)} {
 		set HOMEE $HOME
@@ -662,16 +680,16 @@ proc LoadLoginList {{trigger 0}} {
 	}
 
 	status_log "LoadLoginList: HOME=$HOME, HOME2=$HOME2, HOMEE=$HOMEE\n" blue
-	
-	
+
+
 	set file_id [open "[file join ${HOMEE} profiles]" r]
 	gets $file_id tmp_data
 	if {$tmp_data != "amsn_profiles_version 1"} {	;# config version not supported!
 		#msg_box [trans wrongprofileversion $HOME]
 		close $file_id
-		
+
 		set OLDHOME $HOME
-		
+
 		status_log "LoadLoginList: Recreating profiles file\n" blue
 
 		if { [catch {set file_id [open "[file join ${HOMEE} profiles]" w]}]} {
@@ -694,7 +712,7 @@ proc LoadLoginList {{trigger 0}} {
 			}
 		}
 		close $file_id
-		
+
 		set HOME $OLDHOME
 
 		return [LoadLoginList $trigger]
@@ -705,7 +723,7 @@ proc LoadLoginList {{trigger 0}} {
 	for { set idx 0 } { $idx <= $top } {incr idx 1 } {
 		LoginList unset 0 [LoginList get 0]
 	}
-	
+
 	# Now add profiles from file to list
 	while {[gets $file_id tmp_data] != "-1"} {
 		set temp_data [split $tmp_data]
@@ -722,31 +740,31 @@ proc LoadLoginList {{trigger 0}} {
 			set user_login [::config::getKey login]
 			set HOME $oldHOME
 		}
-		
-		
+
+
 #	    puts "temp data : $temp_data"
 		if { $locknum == "" } {
 		   #Profile without lock, give it 0
 		   set locknum 0
 		}
-		
+
 		LoginList add 0 $user_login $locknum
 		status_log "LoadLoginList: adding profile $user_login with lock num $locknum\n" blue
 	}
 	close $file_id
 
-	
+
 	# Modify HOME dir to current profile, chose a non locked profile, if none available go to default
 	if { $trigger == 0 } {
-		
+
 		#If profiles are disabled, don't load one
 		if { [::config::getGlobalKey disableprofiles] == 1 } {
-			status_log "LoadLoginList: profiles disabled, ignoring\n" blue		
+			status_log "LoadLoginList: profiles disabled, ignoring\n" blue
 			::config::setKey login ""
 			set HOME2 $HOME
 			return
-		}		
-		
+		}
+
 		status_log "LoadLoginList: getting an initial profile\n" blue
 		set HOME2 $HOME
 		set flag 0
@@ -767,9 +785,9 @@ proc LoadLoginList {{trigger 0}} {
 			#set dirname [join $dirname "_"]
 			set HOME "[file join $HOME2 $dirname]"
 			::config::setKey login "$temp"
-			status_log "LoadLoginList: we found a free profile: $temp\n" green		
+			status_log "LoadLoginList: we found a free profile: $temp\n" green
 		} else {
-			status_log "LoadLoginList: using default profile\n" green			
+			status_log "LoadLoginList: using default profile\n" green
 			::config::setKey login ""
 		}
 		SaveLoginList
@@ -789,7 +807,7 @@ proc SaveLoginList {} {
       		set file_id [open "[file join ${HOME2} profiles]" w]
 	}
 	puts $file_id "amsn_profiles_version 1"
-	
+
 	set idx [LoginList size 0]
 	while { $idx >= 0 } {
 		puts $file_id "[LoginList get $idx] [LoginList getlock 0 [LoginList get $idx]]"
@@ -810,7 +828,7 @@ proc SaveLoginList {} {
 #	getlock : Returns lock code for given email, if non existant returns -1.
 #	changelock : changes lock for user given by email to lock port given by lock
 #	lockexists : checks if lock exists for some profile, returns 1 if true, 0 if false
-#	unset : Removes profile given by email from the list and moves 
+#	unset : Removes profile given by email from the list and moves
 #		all elements up by 1 (age is ignored)
 #       size : Returns [array size ProfileList] - 1
 #	show : Dumps list to status_log, for debugging purposes only
@@ -829,7 +847,7 @@ proc LoginList { action age {email ""} {lock ""} } {
 				for {set idx [expr {[array size ProfileList] - 1}]} {$idx >= 0} {incr idx -1} {
 					set ProfileList([expr {$idx + 1}]) $ProfileList($idx)
 					set LockList([expr {$idx + 1}]) $LockList($idx)
-				} 
+				}
 				set ProfileList(0) $email
 				set LockList(0) $lock
 			} else {
@@ -865,7 +883,7 @@ proc LoginList { action age {email ""} {lock ""} } {
 				return 0
 			}
 		}
-		
+
 		exists {
 			set tmp_list [array get ProfileList]
 			set idx [lsearch $tmp_list "$email"]
@@ -875,7 +893,7 @@ proc LoginList { action age {email ""} {lock ""} } {
 				return 1
 			}
 		}
-		
+
 		getlock {
 			set tmp_list [array get ProfileList]
 			set idx [lsearch $tmp_list "$email"]
@@ -907,7 +925,7 @@ proc LoginList { action age {email ""} {lock ""} } {
 				return 1
 			}
 		}
-				
+
 		size {
 			return [expr {[array size ProfileList] - 1}]
 		}
@@ -928,47 +946,47 @@ proc LoginList { action age {email ""} {lock ""} } {
 # email : email of the new profile/login
 proc ConfigChange { window email } {
 	status_log "ConfigChange: $email\n" blue
-	global HOME HOME2 password log_dir lockSock
+	global HOME HOME2 password log_dir webcam_dir lockSock
 
 	if { $email != "" } {
 		status_log "ConfigChange: Valid email\n" green
-		
+
 		if { $email != [::config::getKey login] } {
 			status_log "ConfigChange: Email changed\n" blue
-			
+
 			if { [LoginList exists 0 [::config::getKey login]] == 1 } {
 				save_config
 			}
-		
+
 			if { [LoginList exists 0 $email] == 1 } {
-			
+
 				status_log "ConfigChange: Login exists\n" blue
-				
+
 				# Profile exists, make the switch
 				set OLDHOME $HOME
-				
+
 				set dirname [string map {"@" "_" "." "_"} $email]
 				#set dirname [split $email "@ ."]
 				#set dirname [join $dirname "_"]
 				set HOME "[file join $HOME2 $dirname]"
-						
-				if { [CheckLock $email] == -1 } { 
+
+				if { [CheckLock $email] == -1 } {
 					status_log "ConfigChange: Profile is locked\n" blue
-					
+
 					msg_box [trans profileinuse]
 					set HOME $OLDHOME
-					
+
 					# Reselect previous element in combobox
 					set cb [$window list get 0 [LoginList size 0]]
 					set index [lsearch $cb [::config::getKey login]]
 					$window select $index
 				} else {
 					status_log "ConfigChange: Profile is free\n" green
-				
+
 					if { [info exists password] } {
 						set password ""
 					}
-		
+
 					# Make sure we delete old lock
 					if { [info exists lockSock] } {
 						if { $lockSock != 0 } {
@@ -976,36 +994,44 @@ proc ConfigChange { window email } {
 							unset lockSock
 						}
 					}
-		
+
 					if { [LoginList exists 0 [::config::getKey login]] } {
 						LoginList changelock 0 [::config::getKey login] 0
 					}
-					
+
 					config::setKey login $email
 					load_config
-		
+
 					::config::setKey protocol 9
-		
+
 					LoginList add 0 $email
 					set log_dir "[file join ${HOME} logs]"
-				
+					set webcam_dir "[file join ${HOME} webcam]"
+					create_dir $webcam_dir
+
 					# port isn't taken or port taken by other program, meaning profile ain't locked
 					# let's setup the new lock
 					LockProfile $email
 					SaveLoginList
 					cmsn_draw_offline
-					
+
 				}
 			}
 		}
-		
+
 		if { [winfo exists .login] } {
 			.login.main.f.f.passentry2 delete 0 end
 			if { [info exists password] } {
 				.login.main.f.f.passentry2 insert 0 $password
 			}
+			if {[string is digit -strict "[::config::getKey connectas]"]} {
+				.login.main.f.f.statelist select "[::config::getKey connectas]"
+			} else {
+				.login.main.f.f.statelist select "0"
+				status_log "Variable connectas is not digital [::config::getKey connectas]\n" red
+			}
 		}
-	} 
+	}
 }
 
 
@@ -1014,7 +1040,7 @@ proc ConfigChange { window email } {
 # Switches between default and profiled mode, called from radiobuttons
 # value : If 1 use profiles, if 0 use default profile
 proc SwitchProfileMode { value } {
-	global lockSock HOME HOME2 log_dir loginmode
+	global lockSock HOME HOME2 log_dir webcam_dir loginmode
 
 	if { $value == 1 } {
 		if { $HOME == $HOME2 } {
@@ -1034,8 +1060,8 @@ proc SwitchProfileMode { value } {
 				# Going back to default profile
 				set loginmode 0
 				RefreshLogin .login.main.f.f 1
-			} elseif { $idx > [LoginList size 0] } { 
-				msg_box [trans allprofilesinuse] 
+			} elseif { $idx > [LoginList size 0] } {
+				msg_box [trans allprofilesinuse]
 				# Going back to default profile
 				set loginmode 0
 				RefreshLogin .login.main.f.f 1
@@ -1050,7 +1076,7 @@ proc SwitchProfileMode { value } {
 		}
 	} else {
 		# Switching to default profile, remove lock on previous profiles if needed
-		
+
 		# Make sure we delete old lock
 		if { [info exists lockSock] } {
 			if { $lockSock != 0 } {
@@ -1063,13 +1089,14 @@ proc SwitchProfileMode { value } {
 			SaveLoginList
 		}
 
-		# Load default config 
+		# Load default config
 		set HOME $HOME2
-		
+
 		config::setKey login ""
 		load_config
 		set log_dir ""
-				
+		set webcam_dir ""
+
 		# Set variables for default profile
 		::config::setKey save_password 0
 		::config::setKey keep_logs 0
@@ -1086,8 +1113,8 @@ proc SwitchProfileMode { value } {
 # Creates a new profile
 # email : email of new profile
 proc CreateProfile { email } {
-	global HOME HOME2 log_dir password lockSock loginmode
-	
+	global HOME HOME2 log_dir webcam_dir password lockSock loginmode
+
 	if { [LoginList exists 0 $email] == 1 } {
 		msg_box [trans profileexists]
 		return -1
@@ -1097,37 +1124,39 @@ proc CreateProfile { email } {
 	if { ($HOME == $HOME2) && ([file exists [file join $HOME2 config.xml]] == 0) } {
 		save_config
 	}
-	
+
 	set oldlogin [::config::getKey login]
 
 	status_log "Creating new profile for $email\n" blue
 	# Create a new profile with $email
 	# Set HOME dir and create it
 	set dirname [string map {"@" "_" "." "_"} $email]
-	
+
 	#set dirname [split $email "@ ."]
 	#set dirname [join $dirname "_"]
 	set newHOMEdir "[file join $HOME2 $dirname]"
 	create_dir $newHOMEdir
 	set log_dir "[file join ${newHOMEdir} logs]"
 	create_dir $log_dir
-	
+	set webcam_dir "[file join ${newHOMEdir} webcam]"
+	create_dir $webcam_dir
+
 	# Load default config initially
 	file copy -force [file join $HOME2 config.xml] $newHOMEdir
-	
+
 	set oldhome $HOME
 	set HOME $newHOMEdir
-	
+
 	::config::setKey login $email
 	load_config
 	save_config
-	
+
 	::config::setKey login $oldlogin
 	set HOME $oldhome
 	load_config
 	unset oldhome
 	unset newHOMEdir
-		
+
 	# Add to login list
 	LoginList add 0 $email 0
 	SaveLoginList
@@ -1181,7 +1210,7 @@ proc DeleteProfile { email entrypath } {
 		msg_box [trans cannotdeleteprofile]
 		return
 	}
-	
+
 	set answer [::amsn::messageBox "[trans confirmdelete ${email}]" yesno question]
 
 	if {$answer == "no"} {
@@ -1192,18 +1221,18 @@ proc DeleteProfile { email entrypath } {
 
 	#set dir [split $email "@ ."]
 	#set dir [join $dir "_"]
-	
+
 
 	set entryidx [$entrypath curselection]
 	if {$entryidx == "" } {
 		set entryidx 0
 	}
-	
+
 	catch { file delete -force [file join $HOME2 $dir] }
 	$entrypath list delete $entryidx
 	$entrypath select 0
 	LoginList unset 0 $email
-       
+
 	# Lets save it into the file
 	SaveLoginList
 
@@ -1222,23 +1251,27 @@ proc CheckLock { email } {
 		if { [catch {socket -server phony -myaddr localhost $Port} newlockSock] != 0  } {
 			status_log "CheckLock Port is already in use: $newlockSock\n" red
 			# port is taken, let's make sure it's a profile lock
-			if { [catch {socket localhost $Port} clientSock] == 0 } {
-				status_log "CheckLock: Can connect to port. Sending PING\n" blue
-				fileevent $clientSock readable "lockcltHdl $clientSock"
-				fconfigure $clientSock -buffering line
-				puts $clientSock "AMSN_LOCK_PING"
-				vwait response
-				
-				#set response [gets $clientSock]
-				if { $response == "AMSN_LOCK_PONG" } {
-					status_log "CheckLock: Got PONG response\n" green
-					# profile is locked
-					close $clientSock
-					return -1
-				} else {
-					status_log "CheckLock: another program using port $Port. Reseting to 0\n" blue
-					# other non amsn program is using the lock port, we better reset the lock to 0
-					LoginList changelock 0 $email 0
+			foreach {local_host} { localhost "[info hostname]" 127.0.0.1 } {
+				if {[catch {socket $local_host $Port} clientSock] == 0 } {
+					set done 1
+					status_log "CheckLock: Can connect to port. Sending PING\n" blue
+					fileevent $clientSock readable "lockcltHdl $clientSock"
+					fconfigure $clientSock -buffering line
+					puts $clientSock "AMSN_LOCK_PING"
+					vwait response
+	
+					#set response [gets $clientSock]
+					if { $response == "AMSN_LOCK_PONG" } {
+						status_log "CheckLock: Got PONG response\n" green
+						# profile is locked
+						close $clientSock
+						return -1
+					} else {
+						status_log "CheckLock: another program using port $Port. Reseting to 0\n" blue
+						# other non amsn program is using the lock port, we better reset the lock to 0
+						LoginList changelock 0 $email 0
+					}
+				break
 				}
 			}
 		} else {
@@ -1247,7 +1280,7 @@ proc CheckLock { email } {
 		}
 	} else {
 		status_log "CheckLock: Port is zero\n" blue
-		
+
 	}
 	return 0
 }
@@ -1266,7 +1299,7 @@ proc lockcltHdl { sock } {
 proc GetRandomProfilePort { } {
 
 	set trigger 0
-	
+
 	while { $trigger == 0 } {
 		# Generate random port between 60535 and 65535
 		set Port [expr rand()]
@@ -1297,13 +1330,26 @@ proc LockProfile { email } {
 			set lockSock $newlockSock
 			set trigger 1
 		} else {
-			status_log "Failed to use port $Port: $newlockSock\n" red
+			if { [catch {socket -server lockSvrNew -myaddr [info hostname] $Port} newlockSock] == 0  } {
+				LoginList changelock 0 $email $Port
+				set lockSock $newlockSock
+				set trigger 1
+			} else {
+				if { [catch {socket -server lockSvrNew -myaddr 127.0.0.1 $Port} newlockSock] == 0  } {
+				LoginList changelock 0 $email $Port
+				set lockSock $newlockSock
+				set trigger 1
+				} else {
+					::amsn::errorMsg "Unable to get a socket from locahost.\n Check your /etc/hosts file, please."
+					exit 1
+				}
+			}
 		}
-	
+
 	}
-	if { $trigger == 1 } {
+#	if { $trigger == 1 } {
 		#vwait events
-	}
+#	}
 }
 
 
@@ -1318,24 +1364,64 @@ proc lockSvrNew { sock addr port} {
 
 proc lockSvrHdl { sock } {
 	status_log "lockSvrHdl: handling connection\n" blue
-	
+
 	set command [gets $sock]
-	
+
 	if {[eof $sock]} {
 	    catch {close $sock}
 	    close_remote $sock
 	} else {
 		if { $command == "AMSN_LOCK_PING" } {
 			status_log "lockSvrHdl: PING - PONG\n" blue
-			
+
 			catch {puts $sock "AMSN_LOCK_PONG"}
 		} else {
 		    read_remote $command $sock
 		}
-	   
+
 	}
 }
 
+#///////////////////////////////////////////////////////////////////////
+# WinRegKey ( [addrem] )
+# Adds or removes the registry key to start amsn on startup (windows only)
+# Arguments:
+#  - addrem => choice of adding or removing the registry key: (add/remove)
+# Result: Returns 0/1 for failure/success (note failure could include failure to remove the temporary
+#         file after completion, but the registry key may have still been created/removed
+proc WinRegKey { addrem } {
+	if {$::tcl_platform(platform) == "windows"} {
+		if { [catch { set file_id [open "[file join ${::HOME2} addrem.reg]" w]} res]} {
+			msg_box "Failed to create temporary file with error:\n$res"
+			return 0
+		}
+		puts $file_id "REGEDIT4\n"
+		puts $file_id "\[HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Run\]"
+		if { $addrem == "add" } {
+			set file [string map {"/" "\\\\" " " "\\ "} [info nameofexecutable]]
+			puts $file_id "\"amsn\"=\"\\\"[string map {"/" "\\\\"} [info nameofexecutable]]\\\" \\\"[string map {"/" "\\\\"} [pwd]]\\\\[string map {"/" "\\\\"} [file tail [info script]]]\\\"\"\n"
+		} else {
+			puts $file_id "\"amsn\"=-"
+		}
+		
+		close $file_id
+
+		if { [catch { exec regedit /s [file join ${::HOME2} addrem.reg]} res]} {
+			msg_box "Failed to create/remove the registry key with error:\n$res"
+			return 0
+		}
+		
+		if { [catch { file delete "[file join ${::HOME2} addrem.reg]"} res]} {
+			msg_box "Failed to delete temporary file with error:\n$res"
+			return 0
+		}
+		return 1
+	}
+	return 0
+}
+#///////////////////////////////////////////////////////////////////////
+
+
 #///////////////////////////////////////////////////////////////////////
 # create_dir(path)
 # Creates a directory
@@ -1366,10 +1452,11 @@ if { $initialize_amsn == 1 } {
 	scan_languages
 	::config::configDefaults
 	::config::loadGlobal
-	
+
+
 	load_lang ;#Load default english language
 	load_lang [::config::getGlobalKey language]
-	
+
 	;# Load of logins/profiles in combobox
 	;# Also sets the newest login as config(login)
 	;# and modifies HOME with the newest user
