@@ -8,7 +8,7 @@
 # Configuration of Advertisement Module (banner 234x46)
 #
 #
-# $Id: ctadverts.tcl,v 1.15 2004/08/19 16:11:54 yozko Exp $
+# $Id: ctadverts.tcl,v 1.18 2005/09/01 20:47:02 scapor Exp $
 #
 
 if { $initialize_amsn == 1 } {
@@ -62,9 +62,9 @@ proc resetBanner {} {
 		# This one is not a banner but a branding. When adverts are enabled
 		# they share this space with the branding image. The branding image
 		# is cycled in between adverts.
-		.main.banner configure -background #FFFFFF -image [::skin::loadPixmap logolinmsn]
+		.main.banner configure -background [::skin::getKey bannerbg] -image [::skin::loadPixmap logolinmsn]
 	} else {
-		.main.banner configure -background [::skin::getColor background1] -image [::skin::loadPixmap nullimage]
+		.main.banner configure -background [::skin::getKey mainwindowbg] -image [::skin::loadPixmap nullimage]
 	}
 }
 
