@@ -7,7 +7,7 @@ if { $initialize_amsn == 1 } {
 }
 
 proc dock_handler { sock } {
-        global password
+        global password systemtray_exist
 	set l [gets $sock]
 	
 	if { [eof $sock] || ($l == "SESSION_END") || ($l == "") } {
@@ -15,12 +15,12 @@ proc dock_handler { sock } {
 		fileevent $docksock readable {}
 		close $docksock
 		set docksock 0
-		::config::setKey dock 0
+		set systemtray_exist 0
 		return
 	}
 		
 	if { $l == "GO_INBOX" } {
-		hotmail_login [::config::getKey login] $password
+		::hotmail::hotmail_login [::config::getKey login] $password
 	} elseif { $l == "GO_SIGNINAS" } {
 		cmsn_ns_connect [::config::getKey login] $password
 	} elseif { $l == "GO_SIGNIN" } {
@@ -32,24 +32,24 @@ proc dock_handler { sock } {
 			wm iconify .
 		}
 	} elseif { $l == "GO_ONLINE"} {
-		::MSN::changeStatus NLN
+		ChCustomState NLN
 	} elseif { $l == "GO_NOACT" } {
-		::MSN::changeStatus IDL
+		ChCustomState IDL
 	} elseif { $l == "GO_BUSY" } {
-		::MSN::changeStatus BSY
+		ChCustomState BSY
 	} elseif { $l == "GO_BRB" } {
-			::MSN::changeStatus BRB
+		ChCustomState BRB
 	} elseif { $l == "GO_AWAY" } {
-			::MSN::changeStatus AWY
+		ChCustomState AWY
 	} elseif { $l == "GO_ONPHONE" } {
-		::MSN::changeStatus PHN
+		ChCustomState PHN
 	} elseif { $l == "GO_LUNCH" } {
-		::MSN::changeStatus LUN
+		ChCustomState LUN
 	} elseif { $l == "GO_APP_OFFLINE" } {
-		::MSN::changeStatus HDN
+		ChCustomState HDN
 	} elseif { $l == "OPEN_INBOX" } {
 		global password
-		hotmail_login [::config::getKey login] $password
+		::hotmail::hotmail_login [::config::getKey login] $password
 	} elseif { $l == "SIGNIN" } {
 		global password
 		::MSN::connect
@@ -79,6 +79,8 @@ proc send_dock {type status} {
 
 
 proc close_dock {} {
+	global systemtray_exist
+	
 	mailicon_proc 0
 	statusicon_proc "REMOVE"
 
@@ -89,7 +91,7 @@ proc close_dock {} {
 		close $docksock
 		set docksock 0
 	}
-	::config::setKey dock 0		;# Config is saved before so this don't affect it
+	set systemtray_exist 0
 }
 
 
@@ -118,38 +120,40 @@ proc accept_dock { sock addr cport } {
 }
 
 proc init_dock {} {
-	global systemtray_exist srvSock docksock
+	global systemtray_exist
+	#If the traydock is not disabled
+	if { [::config::getKey use_dock] != 0} {
 
-	if { [::config::getKey dock] != 0} {
-		if { [::config::getKey dock] == 1 } {
-			set svcPort 11983
-			if { [catch {socket -server accept_dock $svcPort} srvSock] } {
-				close_dock
-			}
-		}
-		
-		if { [::config::getKey dock] == 1} {
-
-			if { $docksock != 0 } {
-				close_dock
-				::config::setKey dock 1
-			}
-			catch {exec [file join plugins gnomedock] [file join plugins icons]/ &} res
-		} elseif { [::config::getKey dock] == 2} {
-		} elseif { [::config::getKey dock] == 3} {
+		if {[OnWin]} {
+			trayicon_init
+		} elseif {[OnUnix]} {
+			#We use the freedesktop standard here
 			if { $systemtray_exist == 0 } {
 				trayicon_init
 				if { $systemtray_exist == -1 } {
-					::config::setKey dock 0
-					msg_box "[trans nosystemtray]"
+status_log "dock prob dock.tcl"
+					#Too bad, couldn't load the trayicon
+#					msg_box "[trans nosystemtray]"
 				}
 			}
 			statusicon_proc [::MSN::myStatusIs]
-		} elseif { [::config::getKey dock] == 4} {
-			trayicon_init
-		}
-		
-	} elseif { [::config::getKey dock] == 0 } {
+		}		
+	} else {
 		close_dock
 	}
 }
+
+proc UnixDock { } {
+	if {[::config::getKey use_dock] && [OnUnix] } {
+		return 1
+	} else {
+		return 0
+	}
+}
+proc WinDock { } {
+	if {[::config::getKey use_dock] && [OnWin] } {
+		return 1
+	} else {
+		return 0
+	}
+}
