@@ -1,6 +1,6 @@
 #	Group Administration
 #	by: Ddimo Emilio Grimaldo Tun
-# $Id: groups.tcl,v 1.51 2004/10/01 16:52:29 gadget_boy Exp $
+# $Id: groups.tcl,v 1.54 2005/01/22 21:40:37 burgerman Exp $
 #=======================================================================
 # TODO LIST
 #  - Keep track of transactions pending completion
@@ -217,7 +217,8 @@ namespace eval ::groups {
 		}
 		# The Unique Group ID (MSN) is sent with the RemoveGroup message.
 		# The first group's ID is zero (0) (MSN)
-		set glist [::groups::GetList]
+		set glist [lrange [::groups::GetList] 1 end]
+
 		
 		#Let's sort the groups by name
 		set thelistnames [list]
@@ -560,6 +561,12 @@ namespace eval ::groups {
 		::MSN::WriteSB ns "REG" "$currentGid $new 0"
 		# RenameCB() should be called when we receive the REG
 		# packet from the server
+
+		# If an "add contact" window is open, actualise the group list
+		if { [winfo exists .addcontact] == 1 } {
+			after 500 cmsn_draw_grouplist
+		}
+
 		return 1
 	}
 
@@ -579,6 +586,11 @@ namespace eval ::groups {
 		# MSN sends back "ADG %T %M $gname gid junkdata"
 		# AddCB() should be called when we receive the ADG
 		# packet from the server
+
+		# If an "add contact" window is open, actualise the group list
+		if { [winfo exists .addcontact] == 1 } {
+			after 500 cmsn_draw_grouplist
+		}
 		return 1
 	}
         
@@ -607,6 +619,12 @@ namespace eval ::groups {
 		# MSN sends back "RMG %T %M $gid"
 		# DeleteCB() should be called when we receive the RMG
 		# packet from the server
+
+		# If an "add contact" window is open, actualise the group list
+		if { [winfo exists .addcontact] == 1 } {
+			after 500 cmsn_draw_grouplist
+		}
+
 		return 1
 	}
 
@@ -618,14 +636,14 @@ namespace eval ::groups {
 		set g_entries [array get groups]
 		set items [llength $g_entries]
 		for {set idx 0} {$idx < $items} {incr idx 1} {
-		set var_pk [lindex $g_entries $idx]
-		incr idx 1
-		set var_value [lindex $g_entries $idx]
-		if {$opt != "-names"} {
-			lappend g_list $var_pk	;# Return the key only
-		} else {
-			lappend g_list $var_value;# Return the value only
-		}
+			set var_pk [lindex $g_entries $idx]
+			incr idx 1
+			set var_value [lindex $g_entries $idx]
+			if {$opt != "-names"} {
+				lappend g_list $var_pk	;# Return the key only
+			} else {
+				lappend g_list $var_value;# Return the value only
+			}
 		}
 		set g_list [lsort -increasing $g_list]
 		return $g_list
