@@ -42,9 +42,9 @@ proc StartLog { email } {
 #
 
 proc CheckLogDate {email} {
-    global log_dir
+    global log_dir webcam_dir
 
-    status_log "Opening file\n"
+    #status_log "Opening file\n"
     create_dir $log_dir
 
     if { ![file exists [file join $log_dir date]] } {
@@ -61,42 +61,78 @@ proc CheckLogDate {email} {
 
 
     file stat [file join  $log_dir date] datestat
-    
-    status_log "stating file $log_dir/date = [array get datestat]\n"
 
-    set date [clock format $datestat(mtime) -format "%B %Y"]
+    #status_log "stating file $log_dir/date = [array get datestat]\n"
 
-    status_log "Found date : $date\n" red
-
-    if {  $date != [clock format [clock seconds] -format "%B %Y"] } {
-	status_log "Log was begun in a different month, moving logs\n\n" red
-
-	set to $date
-	set idx 0
-	while {[file exists [file join ${log_dir} $to]] } {
-	    status_log "Directory already used.. .bug? anyways, we don't want to overwrite\n"
-	    set to "${date}.$idx"
-	    incr idx
+	set months "0 January February March April May June July August September October November December"
+	set month [clock format $datestat(mtime) -format "%m"]
+	if { [string range $month 0 0] == "0" } {
+		set month [string range $month 1 1]
 	}
+	set month [lindex $months $month]
+	set year [clock format $datestat(mtime) -format "%Y"]
 
-	catch {file delete [file join ${log_dir} date]}
-
-	create_dir [file join ${log_dir} $to]
-
-	foreach file [glob -nocomplain -types f "${log_dir}/*.log"] {
-	    status_log "moving $file\n" blue
-	    file rename $file [file join ${log_dir} $to]
-	}
+    	set date "$month $year"
 	
-	set fd [open "[file join ${log_dir} date]" w]
-	close $fd
+	set clockmonth [clock format [clock seconds] -format "%m"]
+	if { [string range $clockmonth 0 0] == "0" } {
+		set clockmonth [string range $clockmonth 1 1]
+	}
+	set clockmonth [lindex $months $clockmonth]
+	set clockyear [clock format [clock seconds] -format "%Y"]
+	
+	set clock "$clockmonth $clockyear"
 	
 
+    #status_log "Found date : $date\n" red
 
+    if {  $date != $clock } {
+	    status_log "Log was begun in a different month, moving logs\n" red
+	    
+	    set to $date
+	    set idx 0
+	    while {[file exists [file join ${log_dir} $to]] } {
+		    status_log "Directory already used.. .bug? anyways, we don't want to overwrite\n"
+		    set to "${date}.$idx"
+		    incr idx
+	    }
+	 	   
+	    set cam_to $date
+	    set idx 0
+	    while {[file exists [file join ${webcam_dir} $cam_to]] } {
+		    status_log "Directory already used.. .bug? anyways, we don't want to overwrite\n"
+		    set cam_to "${date}.$idx"
+		    incr idx
+	    }
+
+	    catch {file delete [file join ${log_dir} date]}
+	    
+	    create_dir [file join ${log_dir} $to]
+	    create_dir [file join ${webcam_dir} $cam_to]
+
+	    foreach file [glob -nocomplain -types f "${log_dir}/*.log"] {
+		    status_log "moving $file\n" blue
+		    if {[catch {file rename $file [file join ${log_dir} $to]} res]} {
+		    	status_log "moving file error $res \n"
+		    }
+	    }
+	   	   
+	    foreach file [glob -nocomplain -types f "${webcam_dir}/*.cam"] {
+		    status_log "moving $file\n" blue
+		    if {[catch {file rename $file [file join ${webcam_dir} $cam_to]} res]} {
+		    	status_log "moving file error $res \n"
+		    }
+	    }
+ 
+	    set fd [open "[file join ${log_dir} date]" w]
+	    close $fd
+	    
+	    
+	    
     }
-    
-    return [open "[file join ${log_dir} ${email}.log]" a+]
-
+	
+	return [open "[file join ${log_dir} ${email}.log]" a+]
+	
 }
 
 
@@ -219,23 +255,29 @@ proc StopLog {email {who 0} } {
 # user : user who sent message
 # msg : msg
 
-proc PutLog { chatid user msg } {
+proc PutLog { chatid user msg {fontformat ""}} {
 	
-		set user_list [::MSN::usersInChat $chatid]
-		foreach user_info $user_list {
-			set user_login [lindex $user_info 0]
-			if { [llength $user_list] > 1 } {
-				::log::WriteLog $user_login "\|\"LITA$user \|\"LNOR: $msg\n" 1 $user_list
+	if {$fontformat == ""} {
+		set color "NOR"
+	} else {
+		set color "C[lindex $fontformat 2]"
+	}
+
+	set user_list [::MSN::usersInChat $chatid]
+	foreach user_info $user_list {
+		set user_login [lindex $user_info 0]
+		if { [llength $user_list] > 1 } {
+			::log::WriteLog $user_login "\|\"LITA$user :\|\"L$color $msg\n" 1 $user_list
+		} else {
+			# for 2 windows (1 priv 1 conf)
+			# if conf exists for current user & current chatid is not a conf
+			if { [ConfArray $user_login get] == 1 && $chatid == $user_login} {
+				::log::WriteLog $user_login "\|\"LITA\[[trans linprivate]\] $user :\|\"L$color $msg\n" 2 $user_list
 			} else {
-				# for 2 windows (1 priv 1 conf)
-				# if conf exists for current user & current chatid is not a conf
-				if { [ConfArray $user_login get] == 1 && $chatid == $user_login} {
-					::log::WriteLog $user_login "\|\"LITA\[[trans linprivate]\] $user \|\"LNOR: $msg\n" 2 $user_list
-				} else {
-					::log::WriteLog $user_login "\|\"LITA$user \|\"LNOR: $msg\n" 0 $user_list
-				}
+				::log::WriteLog $user_login "\|\"LITA$user :\|\"L$color $msg\n" 0 $user_list
 			}
 		}
+	}
 }
 
 	
@@ -351,6 +393,7 @@ proc OpenLogWin { {email ""} } {
 			lappend contact_list $contact
 		}
 	}
+
 	#Sorts contacts
 	set sortedcontact_list [lsort -dictionary $contact_list]
 
@@ -381,15 +424,20 @@ proc OpenLogWin { {email ""} } {
 
 	if { [file exists [file join ${log_dir} ${email}.log]] } {
 		set size "[::amsn::sizeconvert [file size "[file join ${log_dir} ${email}.log]"]]o"
+		wm title $wname "[trans history] (${email} - $size)"
 	} else {
-		set size "0Ko"
+		wm title $wname "[trans history] (${email})"
 	}
 
-	wm title $wname "[trans history] (${email} - $size)"
       	wm geometry $wname 600x400
 
 	frame $wname.top
-	frame $wname.blueframe -background [::skin::getColor background1]
+	#No ugly blue frame on Mac OS X, system already put a border around windows
+	if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
+		frame $wname.blueframe
+	} else {
+		frame $wname.blueframe -background [::skin::getKey mainwindowbg]
+	}
 	frame $wname.blueframe.log -class Amsn -borderwidth 0
       	frame $wname.buttons -class Amsn
 
@@ -433,6 +481,7 @@ proc OpenLogWin { {email ""} } {
 	ParseLog $wname $logvar
 
 	button $wname.buttons.close -text "[trans close]" -command "destroy $wname"
+	button $wname.buttons.stats -text "[trans stats]" -command "::log::stats"
 	button $wname.buttons.save -text "[trans savetofile]" -command "::log::SaveToFile ${wname} ${email} [list ${logvar}]"
   	button $wname.buttons.clear -text "[trans clearlog]" \
 				    -command "if { !\[winfo exists $wname.top.date.list\] } { \
@@ -455,6 +504,7 @@ proc OpenLogWin { {email ""} } {
  	pack $wname.blueframe.log -side top -expand true -fill both -padx 4 -pady 4
 	pack $wname.blueframe -side top -expand true -fill both
 	pack $wname.buttons.close -padx 0 -side left
+	pack $wname.buttons.stats -padx 0 -side right
 	pack $wname.buttons.save -padx 0 -side right
 	pack $wname.buttons.clear -padx 0 -side right
 	pack $wname.buttons -side bottom -fill x -pady 3
@@ -465,6 +515,122 @@ proc OpenLogWin { {email ""} } {
 }
 
 
+proc OpenCamLogWin { {email ""} } {
+
+	global webcam_dir langenc logvar
+
+	#Get all the contacts
+	foreach contact [::abook::getAllContacts] {
+		#Selects the contacts who are in our list and adds them to the contact_list
+		if {[string last "FL" [::abook::getContactData $contact lists]] != -1} {
+			lappend contact_list $contact
+		}
+	}
+	#Sorts contacts
+	set sortedcontact_list [lsort -dictionary $contact_list]
+
+	#If there is no email defined, we remplace it by the first email in the dictionary order
+	if {$email == ""} {
+		set email [lindex $sortedcontact_list 0]
+	}
+	
+	set wname [::log::cam_wname $email]
+
+	if { [catch {toplevel ${wname} -borderwidth 0 -highlightthickness 0 } res ] } {
+        	raise ${wname}
+        	focus ${wname}
+		wm deiconify ${wname}
+        	return 0
+      	}
+
+	wm group ${wname} .
+
+	if { [file exists [file join ${webcam_dir} ${email}.cam]] } {
+		set size "[::amsn::sizeconvert [file size "[file join ${webcam_dir} ${email}.cam]"]]o"
+		set exists normal
+	} else {
+		set exists disabled
+		set size "0Ko"
+	}
+
+	wm title $wname "[trans webcamhistory] (${email} - $size)"
+  
+	frame $wname.top
+	#No ugly blue frame on Mac OS X, system already put a border around windows
+	if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
+		frame $wname.blueframe
+	} else {
+		frame $wname.blueframe -background [::skin::getKey mainwindowbg]
+	}
+	frame $wname.blueframe.log -class Amsn -borderwidth 0
+      	frame $wname.buttons -class Amsn
+
+	set img [image create photo ${wname}_img -w 320 -h 240]
+      	label $wname.blueframe.log.l -image $img
+  
+
+
+	frame $wname.top.contact  -class Amsn -borderwidth 0
+	combobox::combobox $wname.top.contact.list -editable true -highlightthickness 0 -width 22 -bg #FFFFFF -font splainf
+	$wname.top.contact.list list delete 0 end
+	foreach contact $sortedcontact_list {
+		$wname.top.contact.list list insert end $contact
+	}
+
+	#Get all the list
+ 	set list [$wname.top.contact.list list get 0 end]
+ 	#Do a search in that list to find where is exactly the email we need
+	set exactMatch [lsearch -exact $list $email]
+  	#Select the email in the list when we open the window with the result of the search
+	$wname.top.contact.list select $exactMatch
+	$wname.top.contact.list configure -command "::log::ChangeCamLogWin $wname $email"
+	$wname.top.contact.list configure -editable false
+
+	pack $wname.top.contact.list -side left
+	pack $wname.top.contact -side left
+
+	::log::CamLogsByDate $wname $email "1"
+
+	button $wname.buttons.play -text "[trans play]" -command "::CAMGUI::Play $img \"[file join ${webcam_dir} ${email}.cam]\"" \
+	    -state $exists
+	button $wname.buttons.pause -text "[trans pause]" -command "::CAMGUI::Pause $img" \
+	    -state $exists
+	button $wname.buttons.stop -text "[trans stop]" -command "::CAMGUI::Stop $img" \
+	    -state $exists
+
+	button $wname.buttons.close -text "[trans close]" -command "destroy $wname"
+#	button $wname.buttons.stats -text "[trans stats]" -command "::log::cam_stats"
+
+  	button $wname.buttons.clear -text "[trans clearlog]" \
+				    -command "if { !\[winfo exists $wname.top.date.list\] } { \
+				                    set date \".\" \
+				              } else {
+				                    set date \[$wname.top.date.list list get \[$wname.top.date.list curselection\]\]\
+					      }
+                                              if { \[::log::ClearCamLog $email \"\$date\"\] } { 
+				                    destroy $wname
+			         	      }" \
+	                            
+	
+
+
+      	
+	pack $wname.top -side top -fill x
+	pack $wname.blueframe.log.l -side left -expand true -fill both
+ 	pack $wname.blueframe.log -side top -expand true -fill both -padx 4 -pady 4
+	pack $wname.blueframe -side top -expand true -fill both
+	pack $wname.buttons.play -padx 0 -side left
+	pack $wname.buttons.pause -padx 0 -side left
+	pack $wname.buttons.stop -padx 0 -side left
+#	pack $wname.buttons.stats -padx 0 -side right
+	pack $wname.buttons.clear -padx 0 -side right
+	pack $wname.buttons.close -padx 0 -side right
+	pack $wname.buttons -side bottom -fill x -pady 3
+	bind $wname <<Escape>> "destroy $wname"
+	bind $wname <Destroy> "::CAMGUI::Stop $img; catch {image delete $img}"
+	moveinscreen $wname 30
+}
+
 proc wname {email} {
 
 	set wname [split $email "@ ."]
@@ -473,6 +639,13 @@ proc wname {email} {
 	return $wname
 }
 
+proc cam_wname {email} {
+
+	set wname [split $email "@ ."]
+	set wname [join $wname "_"]
+	set wname ".${wname}_cam"
+	return $wname
+}
 
 proc LogsByDate {wname email init} {
 
@@ -499,10 +672,18 @@ proc LogsByDate {wname email init} {
 		}
 		set sorteddate_list [lsort -integer -decreasing $date_list]
 
+		set months "0 January February March April May June July August September October November December"
+
 		$wname.top.date.list list insert end "[trans currentdate]"
 		foreach date $sorteddate_list {
-			status_log "Adding date [trans [clock format $date -format "%B"]] [clock format $date -format "%Y"]\n" blue
-			$wname.top.date.list list insert end "[trans [clock format $date -format "%B"]] [clock format $date -format "%Y"]"
+			status_log "Adding date [clock format $date -format "%B"] [clock format $date -format "%Y"]\n" blue
+			set month [clock format $date -format "%m"]
+			if { [string range $month 0 0] == "0" } {
+				set month [string range $month 1 1]
+			}
+			set month "[lindex $months $month]"
+			set year "[clock format $date -format "%Y"]"
+			$wname.top.date.list list insert end "$month $year"
 		}
 		if { $erdate_list != "" } {
 			$wname.top.date.list list insert end "_ _ _ _ _"
@@ -521,6 +702,60 @@ proc LogsByDate {wname email init} {
 	}
 }
 
+proc CamLogsByDate {wname email init} {
+
+	global webcam_dir
+
+	#If we store logs by date
+	if { [::config::getKey logsbydate] == 1 } {
+		#If this is the first log we view
+		if {$init == 1} {
+			frame $wname.top.date  -class Amsn -borderwidth 0
+			combobox::combobox $wname.top.date.list -editable true -highlightthickness 0 -width 22 -bg #FFFFFF -font splainf
+		}			
+		set date_list ""
+		set erdate_list ""
+		$wname.top.date.list list delete 0 end
+		foreach date [glob -nocomplain -types f [file join ${webcam_dir} * ${email}.cam]] {
+			set date [getfilename [file dirname $date]]
+			status_log "Found date $date for log of $email\n"
+			if { [catch { clock scan "1 $date"}] == 0 } {
+				lappend date_list  [clock scan "1 $date"]
+			} else {
+				lappend erdate_list $date
+			}
+		}
+		set sorteddate_list [lsort -integer -decreasing $date_list]
+
+		set months "0 January February March April May June July August September October November December"
+
+		$wname.top.date.list list insert end "[trans currentdate]"
+		foreach date $sorteddate_list {
+			status_log "Adding date [clock format $date -format "%B"] [clock format $date -format "%Y"]\n" blue
+			set month [clock format $date -format "%m"]
+			if { [string range $month 0 0] == "0" } {
+				set month [string range $month 1 1]
+			}
+			set month "[lindex $months $month]"
+			set year "[clock format $date -format "%Y"]"
+			$wname.top.date.list list insert end "$month $year"
+		}
+		if { $erdate_list != "" } {
+			$wname.top.date.list list insert end "_ _ _ _ _"
+			foreach date $erdate_list {
+				status_log "Adding Erroneous date $date\n" red
+				$wname.top.date.list list insert end "$date"
+			}
+		}
+
+		$wname.top.date.list select 0
+
+		$wname.top.date.list configure -command "::log::ChangeCamLogToDate $wname $email"
+		$wname.top.date.list configure -editable false
+		pack $wname.top.date.list -side right
+		pack $wname.top.date -side right
+	}
+}
 
 proc Fileexist {email date} {
 
@@ -572,7 +807,7 @@ proc ChangeLogToDate { w email widget date } {
 
 	global log_dir logvar
 
-	status_log "Changing log for $w to $date\n\n"
+	status_log "Changing log for $email to $date\n" blue
 
 	if { $date == "[trans currentdate]" } {
 		set date "."
@@ -591,20 +826,58 @@ proc ChangeLogToDate { w email widget date } {
 
 	if { [file exists [file join ${log_dir} $date ${email}.log]] } {
 		set size "[::amsn::sizeconvert [file size "[file join ${log_dir} $date ${email}.log]"]]o"
+		wm title $w "[trans history] (${email} - $size)"
 	} else {
-		set size "0Ko"
+		wm title $w "[trans history] (${email})"
 	}
-	wm title $w "[trans history] (${email} - $size)"
+
 
 	ParseLog $w $logvar
 
 }
 
+
+proc ChangeCamLogToDate { w email widget date } {
+
+	global webcam_dir
+
+	status_log "Changing log for $email to $date\n\n"
+
+	if { $date == "[trans currentdate]" } {
+		set date "."
+	}
+	if { $date == "_ _ _ _ _" } {
+		return
+	}
+
+
+	if { [file exists [file join ${webcam_dir} $date ${email}.cam]] } {
+		set size "[::amsn::sizeconvert [file size "[file join ${webcam_dir} $date ${email}.cam]"]]o"
+		set exists normal
+	} else {
+		set size "0Ko"
+		set exists disabled
+	}
+
+	wm title $w "[trans history] (${email} - $size)"
+
+	set img ${w}_img
+
+	::CAMGUI::Stop $img
+
+	$w.buttons.play configure -command "::CAMGUI::Play $img \"[file join ${webcam_dir} $date ${email}.cam]\"" \
+	    -state $exists
+	$w.buttons.pause configure -command "::CAMGUI::Pause $img" \
+	    -state $exists
+	$w.buttons.stop configure -command "::CAMGUI::Stop $img" \
+	    -state $exists
+}
+
 proc ChangeLogWin {w contact widget email} {
 
 	global log_dir logvar date
 
-	status_log "Switch to $email\n\n" blue
+	status_log "Switch to $email\n" blue
 
 	::log::Fileexist $email "."
 
@@ -612,10 +885,10 @@ proc ChangeLogWin {w contact widget email} {
 	$w.blueframe.log.txt delete 0.0 end
 	if { [file exists [file join ${log_dir} ${email}.log]] } {
 		set size "[::amsn::sizeconvert [file size "[file join ${log_dir} ${email}.log]"]]o"
+		wm title $w "[trans history] (${email} - $size)"
 	} else {
-		set size "0Ko"
+		wm title $w "[trans history] (${email})"
 	}
-	wm title $w "[trans history] (${email} - $size)"
 
 	::log::LogsByDate $w $email "0"	
 
@@ -628,7 +901,40 @@ proc ChangeLogWin {w contact widget email} {
 
 }	
 
+proc ChangeCamLogWin {w contact widget email} {
 
+	global webcam_dir date
+
+	status_log "Switch to $email\n\n" blue
+
+	if { [file exists [file join ${webcam_dir} ${email}.cam]] } {
+		set size "[::amsn::sizeconvert [file size "[file join ${webcam_dir} ${email}.cam]"]]o"
+		set exists normal
+	} else {
+		set exists disabled
+		set size "0Ko"
+	}
+
+
+	wm title $w "[trans history] (${email} - $size)"
+
+	::log::CamLogsByDate $w $email "0"	
+
+	set img ${w}_img
+
+	::CAMGUI::Stop $img
+
+	$w.buttons.play configure -command "::CAMGUI::Play $img \"[file join ${webcam_dir} ${email}.cam]\"" \
+	    -state $exists
+	$w.buttons.pause configure -command "::CAMGUI::Pause $img" \
+	    -state $exists
+	$w.buttons.stop configure -command "::CAMGUI::Stop $img" \
+	    -state $exists
+
+
+	catch {$w.top.date.list select 0}
+
+}	
 #///////////////////////////////////////////////////////////////////////////////
 # ParseLog (wname logvar)
 # Decodes the log file and writes to log window
@@ -651,20 +957,39 @@ proc ParseLog { wname logvar } {
 	${wname}.blueframe.log.txt tag configure ITA -foreground blue
 	${wname}.blueframe.log.txt tag configure GRE -foreground darkgreen
 
+	set nbline 0
+
 	set loglines [split $logvar "\n"]
 	set result [list]
 	foreach line $loglines {
+		incr nbline
 		set aidx 0
 		while {$aidx != -1} {
-			set color [string range $line [expr $aidx + 3] [expr $aidx + 5]]
-			set aidx [expr $aidx + 6]
-			set bidx [string first "\|\"L" $line $aidx]
+			# Checks if the line begins by |"L (it happens when we go to the line in the chat window).
+			# If not, use the tags of the previous line
+			if { $aidx == 0 & [string range $line 0 2] != "\|\"L" } {
+				set bidx -1
+			} else {
+				# If the portion of the line begins by |"LC, there is a color information.
+				# The color is indicated by the 6 fingers after it
+				if {[string index $line [expr {$aidx + 3}]] == "C"} {
+					set color [string range $line [expr {$aidx + 4}] [expr {$aidx + 9}]]
+					${wname}.blueframe.log.txt tag configure C_$nbline -foreground "#$color"
+					set color "C_$nbline"
+					incr aidx 10
+				# Else, it is the system with LNOR, LGRA...
+				} else {
+					set color [string range $line [expr {$aidx + 3}] [expr {$aidx + 5}]]
+					incr aidx 6
+				}
+				set bidx [string first "\|\"L" $line $aidx]
+			}
 			if { [string first "\|\"L" $line] == -1 } {
 				set string [string range $line 0 end]
 			} elseif { $bidx != -1 } {
-				set string [string range $line [expr $aidx] [expr $bidx - 1]]
+				set string [string range $line $aidx [expr {$bidx - 1}]]
 			} else {
-				set string [string range $line [expr $aidx] end]
+				set string [string range $line $aidx end]
 			}
 			lappend result $string [list $color]
 			set aidx $bidx
@@ -763,13 +1088,17 @@ proc ParseToFile { logvar filepath } {
 	if { $fileid != 0 } {
 		set aidx 0
 		while {1} {
-			set aidx [expr $aidx + 6]
+			if {[string index $logvar [expr {$aidx + 3}]] == "C"} {
+				incr aidx 10
+			} else {
+				incr aidx 6
+			}
 			set bidx [string first "\|\"L" $logvar $aidx]
 			if { $bidx != -1 } {
-				puts -nonewline $fileid [string range $logvar [expr $aidx] [expr $bidx - 1]]
+				puts -nonewline $fileid [string range $logvar $aidx [expr {$bidx - 1}]]
 				set aidx $bidx
 			} else {
-				puts -nonewline $fileid [string range $logvar [expr $aidx] end]
+				puts -nonewline $fileid [string range $logvar $aidx end]
 				break
 			}
 		}
@@ -805,11 +1134,30 @@ proc ClearLog { email date } {
 	return 1
 }
 
+proc ClearCamLog { email date } {
+
+
+	status_log "ClearCamLog $email $date\n\n"
+	if { $date == "[trans currentdate]" } {
+		set date "."
+	}
+	if { $date == "_ _ _ _ _" } {
+		return 0
+	}
+
+
+	set answer [::amsn::messageBox "[trans confirm]" yesno question [trans clearlog]]
+	if {$answer == "yes"} {	
+		global webcam_dir
+	
+		catch { file delete [file join ${webcam_dir} $date ${email}.cam] }
+	}
+	return 1
+}
 
 #///////////////////////////////////////////////////////////////////////////////
 # ClearAllLogs ()
-# Deletes the all the log files
-#
+# Deletes all the log files
 
 proc ClearAllLogs {} {
 	
@@ -824,6 +1172,20 @@ proc ClearAllLogs {} {
 		create_dir $log_dir
 	}
 
+}
+proc ClearAllCamLogs {} {
+	
+	set parent "."
+	catch {set parent [focus]}
+	set answer [::amsn::messageBox "[trans confirm]" yesno question [trans clearwebcamlogs] $parent]
+	if {$answer == "yes"} {
+
+		global webcam_dir
+
+		catch { file delete -force ${webcam_dir} }
+		create_dir $webcam_dir
+	}
+
 }
 
 #///////////////////////////////////////////////////////////////////////////////
@@ -942,7 +1304,7 @@ proc eventlogout { } {
 
 
 #///////////////////////////////////////////////////////////////////////////////
-#Log what concerns filetransferts
+# Log what concerns filetransferts
 
 proc ftlog {email txt} {
 
@@ -954,9 +1316,290 @@ proc ftlog {email txt} {
 				puts -nonewline $fileid "\|\"LRED\[[trans lconvstarted [clock format [clock seconds] -format "%d %b %Y %T"]]\]\n"
 			}
 			puts -nonewline $fileid "\|\"LGRA[timestamp]\|\"LGRE $txt\n"
-
-
 		}
+		
+		#Postevent when filetrasfer is logged
+		set evPar(email) email
+		set evPar(txt) txt
+		::plugins::PostEvent ft_loged evPar
+		
 }
 
-}
\ No newline at end of file
+
+#///////////////////////////////////////////////////////////////////////////////
+# Sort the contact by the log size
+
+proc sortalllog { } {
+
+	global log_dir
+
+	set contactlist [::abook::getAllContacts]
+	
+	set contactsize [list]
+
+	set months "0 January February March April May June July August September October November December"
+	
+	foreach email $contactlist {
+	
+		set size 0
+		
+		set file "[file join ${log_dir} ${email}.log]"
+	
+		if { [file exists $file] == 1 } {
+			set size [file size $file]
+		}
+		
+		if { [::config::getKey logsbydate] == 1 } {
+			foreach date [glob -nocomplain -types f [file join ${log_dir} * ${email}.log]] {
+				set date [getfilename [file dirname $date]]
+				if { [catch { clock scan "1 $date"}] == 0 } {
+					set date [clock scan "1 $date"]
+					set month [clock format $date -format "%m"]
+					if { [string range $month 0 0] == "0" } {
+						set month [string range $month 1 1]
+					}
+					set month "[lindex $months $month]"
+					set year "[clock format $date -format "%Y"]"
+					set date "$month $year"
+					set file [file join ${log_dir} ${date} ${email}.log]
+					if { [file exists $file] } {
+						incr size [file size $file]
+					}
+				}
+			}
+		}
+		
+		set contactsize [lappend contactsize [list $email $size]]
+	
+	}
+	
+	set contactsize [lsort -integer -index 1 -decreasing $contactsize]
+	
+	return $contactsize
+	
+}
+
+
+proc sortthismonthlog { } {
+
+	global log_dir
+
+	set contactlist [::abook::getAllContacts]
+
+	foreach email $contactlist {
+
+		set file [file join ${log_dir} ${email}.log]
+
+		if { [file exists $file] } {
+			set size [file size $file]
+		} else {
+			set size 0
+		}
+
+	set contactsize [lappend contactsize [list $email $size]]
+
+	}
+
+	set contactsize [lsort -integer -index 1 -decreasing $contactsize]
+	
+	return $contactsize
+
+}
+
+proc sortmonthlog { month } {
+
+	global log_dir
+	
+	set contactlist [::abook::getAllContacts]
+	
+	set contactsize [list]
+	
+	foreach email $contactlist {
+	
+		set file [file join ${log_dir} ${month} ${email}.log]
+			
+		if { [file exists $file] } {
+			set size [file size $file]
+		} else {
+			set size 0
+		}
+		
+		set contactsize [lappend contactsize [list $email $size]]
+		
+	}
+	
+	set contactsize [lsort -integer -index 1 -decreasing $contactsize]
+	
+	return $contactsize
+	
+}
+
+
+
+proc getAllDates { } {
+
+	if { [::config::getKey logsbydate] == 1 } {
+
+		global log_dir
+		
+		set datelist [list]
+		set datelisterror [list]
+	
+		foreach date [glob -nocomplain -types d -path "${log_dir}/" *] {
+			set idx [expr {[string last "/" $date] + 1}]
+			set date2 [string range $date $idx end]
+		
+			if { [catch {
+				set date2 [clock scan "1 $date2"]
+				set datelist [lappend datelist $date2]
+			} ] } {
+				set datelisterror [lappend datelisterror $date2]
+			}
+		}
+	
+		set datelist [lsort -integer -decreasing $datelist]
+
+		set datelist2 [list]
+
+		set months "0 January February March April May June July August September October November December"
+
+
+		foreach date $datelist {
+			set month [clock format $date -format "%m"]
+			if { [string range $month 0 0] == "0" } {
+				set month [string range $month 1 1]
+			}
+			set month "[lindex $months $month]"
+			set year "[clock format $date -format "%Y"]"
+			set date "$month $year"
+			set datelist2 [lappend datelist2 $date]
+		}
+	
+		set datelist2 [concat $datelist2 $datelisterror]
+	
+		return $datelist2
+
+	} else {
+	
+		return ""
+		
+	}
+	
+}
+
+
+#///////////////////////////////////////////////////////////////////////////////
+# Make a stats window
+
+proc stats { } {
+
+	set w .stats
+	
+	if { [winfo exists $w] } {
+		raise $w
+		return
+	}
+
+	toplevel $w
+	
+	wm title $w "[trans stats]"
+	wm geometry $w 300x390
+		
+	set months [::log::getAllDates]
+	
+	frame $w.select
+	label $w.select.text -text [trans stats] -font bigfont
+	combobox::combobox $w.select.list -editable true -highlightthickness 0 -width 15 -bg #FFFFFF -font splainf
+	$w.select.list list delete 0 end
+		
+	$w.select.list list insert end "[trans allmonths]"
+	$w.select.list select "0"
+
+	$w.select.list list insert end "[trans thismonth]"
+	
+	foreach month $months {
+		$w.select.list list insert end "$month"
+	}
+	pack configure $w.select.text -side top	
+	pack configure $w.select.list -side right
+	pack configure $w.select -side top -fill x -expand false
+	
+	ScrolledWindow $w.list
+	ScrollableFrame $w.list.sf -constrainedwidth 1
+	$w.list setwidget $w.list.sf
+	pack $w.list -anchor n -side top -fill both -expand true
+	set frame [$w.list.sf getframe]
+	
+	set contactsize [::log::sortalllog]
+	
+	set id 0
+
+	foreach contact $contactsize {
+		set email [lindex $contact 0]
+		set size [lindex $contact 1]
+		if { $size == 0 } {
+			break
+		}
+		incr id
+		set wlabel "label_$id"
+		label $frame.$wlabel -text "$id) $email ([::amsn::sizeconvert $size]b)"
+		pack configure $frame.$wlabel -side top
+	}
+	
+	$w.select.list configure -editable false -command "::log::stats_select $id"
+
+	#frame $w.button
+	button $w.close -text "[trans close]" -command "destroy $w"
+	pack configure $w.close -side bottom -padx 10 -pady 10
+	#pack configure $w.button -side bottom -fill x -expand true
+	
+	bind $w <<Escape>> "destroy $w"
+	moveinscreen $w 30
+	
+	
+}
+
+
+proc stats_select { id wname month} {
+
+	set w .stats
+	
+	set frame [$w.list.sf getframe]
+	
+	for {set i 1} {$i<=$id} {incr i} {
+		set wlabel "label_$i"
+		destroy $frame.$wlabel
+	}
+	
+	if { [$w.select.list curselection] == 0} {
+		set contactsize [::log::sortalllog]
+	} elseif { [$w.select.list curselection] == 1 } {
+		set contactsize [::log::sortthismonthlog]
+	} else {
+		set contactsize [::log::sortmonthlog $month]
+	}
+	
+	set id 0
+	
+	foreach contact $contactsize {
+		set email [lindex $contact 0]
+		set size [lindex $contact 1]
+		if { $size == 0 } {
+			break
+		}
+		incr id
+		set wlabel "label_$id"
+		label $frame.$wlabel -text "$id) $email ([::amsn::sizeconvert $size]b)"
+		pack configure $frame.$wlabel -side top
+	}
+	
+	$w.select.list configure -editable false -command "::log::stats_select $id"
+	$w.list.sf yview moveto 0
+	
+	
+}
+
+
+
+
+}
