@@ -1,5 +1,5 @@
 #
-# $Id: smileys.tcl,v 1.127 2004/09/24 13:57:19 airadier Exp $
+# $Id: smileys.tcl,v 1.156 2005/10/09 23:03:35 roadkillbunny Exp $
 #
 
 if { $initialize_amsn == 1 } {
@@ -61,7 +61,7 @@ namespace eval ::smiley {
 		#This is only checked if ::loading_skin is set. Otherwise we're
 		#loading the default skin to get the standard smileys
 		if { [info exists ::loading_skin] } {
-			set realfile [GetSkinFile smileys $emotion(file) $::loading_skin]
+			set realfile [::skin::GetSkinFile smileys $emotion(file) $::loading_skin]
 			if { [file tail $realfile] == "null" } {
 				status_log "Missing $emotion(file) from skin $::loading_skin. Using default\n" red
 				return 0
@@ -77,7 +77,8 @@ namespace eval ::smiley {
 			#Trim text (remove " ") and ignore empty strings
 			if { $text == "" } { continue }
 			set text [string trim $text \"]
-			set text [string tolower $text]
+			#some smileys are case sensitive, like the moon!
+			#set text [string tolower $text]
 			
 			#Delete any previous ocurrence of this smiley if this existed and skin
 			#propertie was set to "" (loaded when loading default skin first)
@@ -109,7 +110,7 @@ namespace eval ::smiley {
 			
 			
 			#Associate this symbol to this file for skin reloading
-			::skin::setSmiley $text $emotion(file)
+			::skin::setPixmap $text $emotion(file) smileys
 		}
 		
 		#Store the smiley fields in the emotions_data array
@@ -159,19 +160,64 @@ namespace eval ::smiley {
 			set emotion($field_sort) [string trim $sdata($field)]
 		}
 		#Create the image now and store it
-		set emotion(image_name) [image create photo -file $emotion(file) -format gif]
+		if { [catch { image create photo -file $emotion(file) -format cximage } emotion(image_name) ] } {
+			status_log "Error when creating image for emoticon $emotion(name) : $emotion(image_name)"
+			#Error when creating smiley's image so we don't add it
+			return 0
+		}
 		
-		#Add to the list of custom emoticons
-		lappend [::config::getVar customsmileys] $emotion(name)
 		#Store the emoticon data in the custom_emoticons array
 		set custom_emotions($emotion(name)) [array get emotion]
-		#Create the image, and associate it
 
+		variable sortedemotions
+		if {[info exists sortedemotions]} { unset sortedemotions }
+		
 		
 		return 0
 	}
 	
 
+	
+	#///////////////////////////////////////////////////////////////////////////////
+	# proc SortSmileys
+	#
+	# Create a list of available smileys, sorted by symbol length
+	proc SortSmileys {} {
+		global emotions
+		global custom_emotions
+			
+		variable sortedemotions
+		
+		#If no sorted list exists, create it...
+		if { ![info exists sortedemotions]} {
+			set unsortedemotions [list]
+			
+			#Add standard smileys. We just add the symbol, and keyword "standard"
+			foreach name [array names emotions] {
+				lappend unsortedemotions [list $name standard]
+			}
+			
+			#Add our custom smileys. For custom smileys we also add
+			#the smiley name associated to that symbol
+			foreach name [array names custom_emotions] {
+			
+				if { ![info exists custom_emotions($name)] } {
+					status_log "substYourSmileys: Custom smiley $name doesn't exist in custom_emotions array!!\n" red
+					continue
+				}
+			
+				array set emotion $custom_emotions($name)
+				foreach symbol $emotion(text) {
+					lappend unsortedemotions [list $symbol custom $name]
+				}
+			}
+			
+#TODO: Add SB smileys?
+
+			#Now, sort this list			
+			set sortedemotions [lsort -command ::smiley::CompareSmileyLength $unsortedemotions]
+		}
+	}
 
 	#///////////////////////////////////////////////////////////////////////////////
 	# proc substSmileys { tw {start "0.0"} {end "end"} {contact_list 0} }
@@ -184,46 +230,98 @@ namespace eval ::smiley {
 	# the function scans the text widget (from the $start variable to the end) and
 	# replaces any smileys pattern by the appropriate image (animated or not) and plays
 	# a sound if necessary, etc... It scans the widget for every smiley that exists
-	proc substSmileys {tw {textbegin "0.0"} {end "end"} {contact_list 0}} {
+	proc substSmileys {tw {textbegin "0.0"} {end "end"} {contact_list 0} {include_custom 0}} {
 		global emotions
+		global custom_emotions
 		variable sortedemotions
+				
+		SortSmileys
 		
-		if { ![info exists sortedemotions]} {
-			set sortedemotions [lsort -command ::smiley::CompareSmileyLength [array names emotions]]
-		}
+		set scrolling [::ChatWindow::getScrolling $tw]
+			
+		#Search for all possible emotions, after they are sorted by symbol length
+		foreach emotion_data $sortedemotions {
 		
-		#Search for all possible emotions
-		foreach symbol $sortedemotions {
+			#Symbol is first element
+			set symbol [lindex $emotion_data 0]
+			#Type is second element
+			set smiley_type [lindex $emotion_data 1]
 			
-			#Get the name for this symbol
-			set emotion_name $emotions($symbol)
-
-			if { [ValueForSmiley $emotion_name casesensitive 1] } {set nocase "-exact"} else {set nocase "-nocase"}
-			
-			set start $textbegin
-			
-			#Keep searching umtil no matches
-			while {[set pos [$tw search -exact $nocase -- $symbol $start $end]] != ""} {
-		
-				set animated [ValueForSmiley $emotion_name animated 1]
+			if { $smiley_type == "custom" } {
+				#If smiley type is custom, replace or ignore it depending on call parameter
+				if { $include_custom == 0} {
+					continue
+				} else {
+					#Get name. It will be 3rd element on the list
+					set name [lindex $emotion_data 2]
+					
+					#Get all emoticon data from custom_emotions array
+					array set emotion $custom_emotions($name)
+					
+					if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)]} {
+						set nocase "-exact"
+					} else {
+						set nocase "-nocase"
+					}
+					
+					set animated [expr {[info exists emotion(animated)] && [is_true $emotion(animated)]}]
+					if { $contact_list == 0 && [info exists emotion(sound)] && $emotion(sound) != "" } {
+						set sound $emotion(sound)
+					} else { set sound "" }
+					set image_name $emotion(image_name)
+					set image_file $emotion(file)
+					
+					
+					array unset emotion
+				}
+				
+			} else {
+				#Get the name for this symbol
+				set emotion_name $emotions($symbol)
+	
+				if { [ValueForSmiley $emotion_name casesensitive 1] } {
+					set nocase "-exact"
+				} else {
+					set nocase "-nocase"
+				}
+				
+				set animated [ValueForSmiley $emotion_name animated 1]			
 				if { $contact_list == 0 && [ValueForSmiley $emotion_name sound] != "" } {
 					set sound [ValueForSmiley $emotion_name sound]
 				} else { set sound "" }
+				set image_name [::skin::loadPixmap $symbol smileys]
+				set image_file [ValueForSmiley $emotion_name file]
 				
-				set start [::smiley::SubstSmiley $tw $pos $symbol [::skin::loadSmiley $symbol] [ValueForSmiley $emotion_name file] $animated $sound]
-		
+				set start $textbegin
+
+			}
+
+			
+			#Keep searching until no matches
+			set start $textbegin
+			while {[set pos [$tw search -exact $nocase -- $symbol $start $end]] != ""} {
+			
+				
+				set start [::smiley::SubstSmiley $tw $pos $symbol $image_name $image_file $animated $sound]
 				#If SubstSmiley returns -1, start from beggining.
 				#See why in SubstSmiley. This is a fix
 				if { $start == -1 } { set start $textbegin }
-
 		
 			}
 			
+			
+			
+			
 		}
+		
+		if { $scrolling } { ::ChatWindow::Scroll $tw }
 	
 	}
 	
-	#Replace one smiley in the given $tw (text window)
+	#//////////////////////////////////////////////////////////////////////
+	# proc SubstSmiley {tw pos symbol image file animated sound }
+	#
+	# Replace one smiley in the given $tw (text window)
 	proc SubstSmiley { tw pos symbol image file animated { sound "" }} {
 
 		set chars [string length $symbol]
@@ -238,33 +336,8 @@ namespace eval ::smiley {
 		$tw tag configure smiley -elide true
 		$tw tag add smiley $pos $endpos
 	
-		if { $animated && [::config::getKey animatedsmileys] } {
-			global smileys_drawn
-			set emoticon "$tw.${smileys_drawn}"
-			incr smileys_drawn 
-	
-			label $emoticon -bd 0 -background white
-			::anigif::anigif [GetSkinFile smileys $file] $emoticon
-	
-			#TODO: I just added this to avoid a bug I can't find... someday we can fix it
-			catch {
-				$tw window create $endpos -window $emoticon
-				bind $emoticon <Destroy> [list ::anigif::destroy $emoticon]
-				$tw tag remove smiley $endpos
-			}
-	
-			#Preserver replaced text tags
-			set tagname  [$tw tag names $endpos]
-			if { [llength $tagname] == 1 } {
-				bind $emoticon <Button3-ButtonRelease> [$tw tag bind $tagname <Button3-ButtonRelease>]
-				bind $emoticon <Enter> [$tw tag bind $tagname <Enter>]
-				bind $emoticon <Leave> [$tw tag bind $tagname <Leave>]
-			}
-
-		} else {
-			$tw image create $endpos -image $image -pady 0 -padx 0
-			$tw tag remove smiley $endpos
-		}
+		$tw image create $endpos -image $image -pady 0 -padx 0
+		$tw tag remove smiley $endpos
 
 		if { [::config::getKey emotisounds] == 1 && $sound != "" } {
 			play_sound $sound
@@ -275,42 +348,7 @@ namespace eval ::smiley {
 		#so we restart from beginning
 		return -1
 	}
-	
-	# proc substYourSmileys { tw {start "0.0"} {end "end"} {contact_list 0} }
-	#
-	# Similar to substSmileys, but replace only your custom smileys
-	proc substYourSmileys {tw {textbegin "0.0"} {end "end"} {contact_list 0}} {
-		global custom_emotions
 		
-		#Search for all possible emotions
-		foreach name [::config::getKey customsmileys] {
-	
-			array set emotion $custom_emotions($name)
-			foreach symbol $emotion(text) {
-			
-				if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)]} {set nocase "-exact"} else {set nocase "-nocase"}
-				
-				set start $textbegin
-				
-				#Keep searching umtil no matches
-				while {[set pos [$tw search -exact $nocase -- $symbol $start $end]] != ""} {
-				
-					set animated [expr {[info exists emotion(animated)] && [is_true $emotion(animated)]}]
-					if { $contact_list == 0 && [info exists emotion(sound)] && $emotion(sound) != "" } {
-						set sound $emotion(sound)
-					} else { set sound "" }
-					
-					set start [::smiley::SubstSmiley $tw $pos $symbol $emotion(image_name) $emotion(file) $animated $sound]
-					#If SubstSmiley returns -1, start from beggining.
-					#See why in SubstSmiley. This is a fix
-					if { $start == -1 } { set start $textbegin }
-			
-				}
-			}
-		}
-	
-	}
-	
 	
 	#///////////////////////////////////////////////////////////////////////////////
 	# proc smileyMenu { {x 0} {y 0} {text text}}
@@ -328,8 +366,8 @@ namespace eval ::smiley {
 		if { ! [winfo exists $w]} { CreateSmileyMenu }
 		
 		wm state $w normal
-		set x [expr $x - 15]
-		set y [expr $y + 15 - [winfo height $w]]
+		set x [expr {$x - 15}]
+		set y [expr {$y + 15 - [winfo height $w]}]
 		wm geometry $w +$x+$y
 		#It won't work on Windows without this
 		update idletasks
@@ -363,7 +401,7 @@ namespace eval ::smiley {
 		
 		#Now add custom emotions bindings
 		global custom_emotions
-		foreach name [::config::getKey customsmileys] {
+		foreach name [array names custom_emotions] {
 			array set emotion $custom_emotions($name)
 			set symbol [lindex $emotion(text) 0]
 			
@@ -393,17 +431,142 @@ namespace eval ::smiley {
 		event generate $w <Enter>
 	
 	}
+
+
+	#//////////////////////////////////////////////////////////////////
+	#proc that changes a string into a list with seperated text/smileys
+	proc parseMessageToList { name {contact_list 0} {include_custom 0} } {
+		global emotions
+		global custom_emotions
+		variable sortedemotions
+
+		#This is a poor place for sort smileys should be done only when adding new smileys to the list?
+		#SortSmileys
+
+		set l [list [ list "text" "$name" ]]
+		set llength 1
+
+		#Search for all possible emotions, after they are sorted by symbol length
+		foreach emotion_data [concat $sortedemotions [list [list "\n" "newline"]]] {
+
+			#Symbol is first element
+			set symbol [lindex $emotion_data 0]
+			#Type is second element
+			set smiley_type [lindex $emotion_data 1]
+
+			if { $smiley_type == "custom" } {
+				#If smiley type is custom, replace or ignore it depending on call parameter
+				if { $include_custom == 0} {
+					continue
+				} else {
+					#Get name. It will be 3rd element on the list
+					set name [lindex $emotion_data 2]
+
+					#Get all emoticon data from custom_emotions array
+					array set emotion $custom_emotions($name)
+
+					if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)]} {
+						set nocase "-exact"
+					} else {
+						set nocase "-nocase"
+					}
+		
+					set animated [expr {[info exists emotion(animated)] && [is_true $emotion(animated)]}]
+					if { $contact_list == 0 && [info exists emotion(sound)] && $emotion(sound) != "" } {
+						set sound $emotion(sound)
+					} else {
+						set sound ""
+					}
+					set image_name $emotion(image_name)
+					set image_file $emotion(file)
+		
+		
+					array unset emotion
+				}
+		
+			} elseif { $smiley_type == "newline" } {
+				set emotion_name "newline"
+				set nocase "-exact"
+				set animated 0
+				set sound ""
+				set image_name "__newline__"
+				set image_file ""
+			} else {
+				#Get the name for this symbol
+				set emotion_name $emotions($symbol)
+	
+				if { [ValueForSmiley $emotion_name casesensitive 1] } {
+					set nocase "-exact"
+				} else {
+					set nocase "-nocase"
+				}
+	
+				set animated [ValueForSmiley $emotion_name animated 1]
+				if { $contact_list == 0 && [ValueForSmiley $emotion_name sound] != "" } {
+					set sound [ValueForSmiley $emotion_name sound]
+				} else {
+					set sound ""
+				}
+				set image_name [::skin::loadPixmap $symbol smileys]
+				set image_file [ValueForSmiley $emotion_name file]
+			}
+
+			set listpos 0
+			#Keep searching until no matches
+#TODO: make it not case sensitive
+			while { $listpos < $llength } {
+				if { ([lindex $l $listpos 0] != "text") } {
+					incr listpos
+					continue
+				}
+				
+				if {[set pos [string first $symbol [lindex $l $listpos 1]]] != -1 } {
+					set p1 [string range [lindex $l $listpos 1] 0 [expr {$pos - 1}]]
+					set p2 $image_name
+					set p3 [string range [lindex $l $listpos 1] [expr {$pos + [string length $symbol]}] end]
+
+#TODO: #need to change for an 'in-place' lreplace (here and below)
+					if { $p2 == "__newline__" } {
+						set l [lreplace $l $listpos $listpos [list text $p1] [list "newline"] [list text $p3] ]
+					} else {
+						set l [lreplace $l $listpos $listpos [list text $p1] [list smiley $p2] [list text $p3] ]
+					}
+
+					incr llength 2
+					
+					if { $p3 == "" } {
+						set listpos2 [expr {$listpos + 2}]
+						set l [lreplace $l $listpos2 $listpos2]
+						incr llength -1
+					}
+					if { $p1 == "" } {
+						set l [lreplace $l $listpos $listpos]
+						incr llength -1
+						incr listpos -1
+					}
+				}
+				#text can never be followed by another set of text
+				incr listpos 2
+			}
+		}
+
+#TODO: also parse newlines as [list newline]
+
+		return $l
+	}
+
+
 	
 	#Create ONE smiley in the smileys menu
 	proc CreateSmileyInMenu {w cols rows smiw smih emot_num name symbol image file animated} {
 		catch {
-			if { $animated } {
-				label $w.$emot_num -background [$w cget -background]
-				::anigif::anigif  $file $w.$emot_num
-				bind $w.$emot_num <Destroy> [list ::anigif::destroy $w.$emot_num]
-			} else {
-				label $w.$emot_num -image $image -background [$w cget -background]
+			set resized [image create photo]
+			$resized copy $image
+			if {[image width $image] > 22 && [image height $image] > 22} {
+				::picture::ResizeWithRatio $resized 22 22
 			}
+			label $w.$emot_num -image $resized -background [$w cget -background]
+			bind $w.$emot_num <Destroy> "image delete $resized"
 	
 			$w.$emot_num configure -cursor hand2 -borderwidth 1 -relief flat
 			
@@ -411,8 +574,8 @@ namespace eval ::smiley {
 			bind $w.$emot_num <Enter>  [list $w.$emot_num configure -relief raised]
 			bind $w.$emot_num <Leave> [list $w.$emot_num configure -relief flat]
 
-			#Toolstip
-			if { [::config::getKey tooltips] } {set_balloon $w.$emot_num "$name $symbol"}
+			#Tooltip
+			if { [::config::getKey tooltips] } {set_balloon $w.$emot_num "$name\n[trans triggers]: $symbol" "$image"}
 			set xpos [expr {($emot_num % $cols)* $smiw}]
 			set ypos [expr {($emot_num / $cols) * $smih}]
 			$w create window $xpos $ypos -window $w.$emot_num -anchor nw -width $smiw -height $smih
@@ -426,7 +589,7 @@ namespace eval ::smiley {
 	# To get the width and height of the menu, then it creates the menu withdrawn with 
 	# the animated smileys and static smileys in the correct order
 	proc CreateSmileyMenu { } {
-		global emotions emotions_names skinconfig custom_emotions
+		global emotions emotions_names custom_emotions
 
 		set w .smile_selector
 		if {[catch {[toplevel $w]} res]} {
@@ -436,11 +599,12 @@ namespace eval ::smiley {
 		
 		#Calculate the total number of smileys (including custom ones)
 		set emoticon_number [llength $emotions_names]
-		incr emoticon_number [llength [::config::getKey customsmileys]]
+		incr emoticon_number [llength [array names custom_emotions]]
 		
 		#Fixed smiley size
 		set smiw 26
 		set smih 26
+	
 		
 		#We want to keep a certain ratio:
 		# cols/(rows+1) = 4/3
@@ -451,11 +615,11 @@ namespace eval ::smiley {
 		set rows [expr {ceil(double($emoticon_number) / $cols)+1}]
 
 		#status_log "Smileys: $emoticon_number. Cols: $cols. Rows: $rows\n" white
-		set cols [expr int($cols)]
-		set rows [expr int($rows)]
+		set cols [expr {int($cols)}]
+		set rows [expr {int($rows)}]
 		
-		set x_geo [expr $smiw*$cols +2 ]
-		set y_geo [expr $smih*$rows +2 ]
+		set x_geo [expr {$smiw*$cols + 2} ]
+		set y_geo [expr {$smih*$rows + 2} ]
 		
 		
 		wm state $w withdrawn
@@ -480,7 +644,7 @@ namespace eval ::smiley {
 			set animated [expr {[ValueForSmiley $name animated 1] && [::config::getKey animatedsmileys 0]}]
 			
 			CreateSmileyInMenu $w.c $cols $rows $smiw $smih \
-				$emot_num $name $symbol [::skin::loadSmiley $symbol] [GetSkinFile smileys ${file}] $animated
+				$emot_num $name $symbol [::skin::loadPixmap $symbol smileys] [::skin::GetSkinFile smileys ${file}] $animated
 
 			incr emot_num
 		
@@ -488,7 +652,7 @@ namespace eval ::smiley {
 		
 		#Now add custom emotions
 		global custom_emotions
-		foreach name [::config::getKey customsmileys] {
+		foreach name [array names custom_emotions] {
 		
 			array set emotion $custom_emotions($name)
 			if {![info exists emotion(animated)]} { set emotion(animated) 0 }
@@ -507,7 +671,7 @@ namespace eval ::smiley {
 		bind $w.c.custom_new <Button1-ButtonRelease> "::smiley::newCustomEmoticonGUI; event generate $w <Leave>"
 		
 		set ypos [expr {(($rows-1)*$smih + ($smih/2))}]
-		$w.c create window  0 $ypos -window $w.c.custom_new -width [expr $x_geo - 2] -height $smih -anchor w
+		$w.c create window  0 $ypos -window $w.c.custom_new -width [expr {$x_geo - 2}] -height $smih -anchor w
 		
 		
 		bind $w <Enter> "bind $w <Leave> \"bind $w <Leave> \\\"wm state $w withdrawn\\\"\""
@@ -551,7 +715,6 @@ namespace eval ::smiley {
 		button $w.browsesound -text "[trans browse]" -command [list chooseFileDialog "" "" .new_custom $w.sound open \
 			[list [list [trans soundfiles] [list *.wav *.mp3 *.au *.ogg]] [list [trans allfiles] *]]] -width 10 
 		checkbutton $w.enablesound -text "[trans enablesound]" -onvalue 1 -offvalue 0 -variable new_custom_cfg(enablesound) -command ::smiley::UpdateEnabledSoundSmileys -font sboldf
-		checkbutton $w.animated -text "[trans animatedemoticon]" -onvalue 1 -offvalue 0 -variable new_custom_cfg(animated) -font sboldf
 		checkbutton $w.casesensitive -text "[trans casesensitive]" -onvalue 1 -offvalue 0 -variable new_custom_cfg(casesensitive) -font sboldf
 		
 		frame .new_custom.buttons -class Degt
@@ -596,7 +759,6 @@ namespace eval ::smiley {
 		grid $w.browsesound -row 4 -column 2 -padx 2 -pady 2 -sticky w
 		
 		grid $w.enablesound -row 5 -column 1 -columnspan 2 -padx 2 -pady 2 -sticky w
-		grid $w.animated -row 6 -column 1 -columnspan 2 -padx 2 -pady 2 -sticky w
 		
 		grid $w.casesensitive -row 7 -column 1 -columnspan 2 -padx 2 -pady 2 -sticky w
 		
@@ -622,13 +784,12 @@ namespace eval ::smiley {
 	proc NewCustomEmoticonGUI_Delete { name } {
 		global custom_emotions
 		
-		set idx [lsearch [::config::getKey customsmileys] $name]
-		if { $idx != -1 } {
-			::config::setKey customsmileys [lreplace [::config::getKey customsmileys] $idx $idx]
-		}
 		unset custom_emotions($name)
 		if { [winfo exists .smile_selector]} {destroy .smile_selector}
 		
+		#After modifying, clear sortedemotions, could need sorting again
+		variable sortedemotions
+		if {[info exists sortedemotions]} { unset sortedemotions }
 		
 		destroy .new_custom
 
@@ -706,14 +867,14 @@ namespace eval ::smiley {
 		
 		#Check for sound, and copy it
 		if { $new_custom_cfg(enablesound) && $new_custom_cfg(sound) != "" } {
-			set filename [getfilename [GetSkinFile sounds $new_custom_cfg(sound)]]
+			set filename [getfilename [::skin::GetSkinFile sounds $new_custom_cfg(sound)]]
 			if { $filename == "null" } {
 				#if { [info exists custom_emotions(${name}_sound)] } {unset custom_emotions(${name}_sound)}
 				msg_box "[trans invalidfile [trans soundfile] \"$new_custom_cfg(sound)\"]"
 				return -1
 			} else {
 				create_dir [file join $HOME sounds]
-				catch { file copy [GetSkinFile sounds "$new_custom_cfg(sound)"] [file join $HOME sounds]}
+				catch { file copy [::skin::GetSkinFile sounds "$new_custom_cfg(sound)"] [file join $HOME sounds]}
 			}
 			set emotion(sound) $filename
 			#set custom_emotions(${name}_sound) "$filename"
@@ -723,20 +884,73 @@ namespace eval ::smiley {
 			if { [info exists emotion(sound)] } { unset emotion(sound) }
 		}
 		
-		set filename [getfilename [GetSkinFile smileys $new_custom_cfg(file)]]
+		set filename [getfilename [::skin::GetSkinFile smileys $new_custom_cfg(file)]]
 		if { $filename == "null" } {
 			msg_box "[trans invalidfile [trans smilefile] \"$new_custom_cfg(file)\"]"
 			return -1
 		} 
 		
 		create_dir [file join $HOME smileys]
-		set file [convert_image_plus [GetSkinFile smileys "$new_custom_cfg(file)"] smileys 19x19]
+		
+		#Check for animation
+		if { [ catch {set emotion(animated) [::picture::IsAnimated [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] ] } res ] } {
+			#There is an error with the file, wront format or doesn't exist
+			msg_box "$res"
+			return -1
+		}
+		if { $emotion(animated) == 0 } { unset emotion(animated) }
+		
+		if { ![info exists emotion(animated)] || $emotion(animated) == 0 } {
+			if { $edit == 1 } {
+				set titleid custom_edit
+			} else {
+				set titleid custom_new
+			}
+			image create photo temp_smiley -file [::skin::GetSkinFile smileys "$new_custom_cfg(file)"]
+			
+			set filetail_noext [filenoext [file tail "$new_custom_cfg(file)"]]
+			set destfile [file join $HOME smileys $filetail_noext]
+			
+			if { [image width temp_smiley] > 19 || [image height temp_smiley] > 19 } {
+				#Smiley is static and bigger than 19x19 we ask for resizing
+				if { [::amsn::messageBox "[trans smiletoobig]" yesno question "[trans $titleid ]"] == "yes" } {
+					#The user wants resize it
+					set file [convert_image_plus [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] smileys 19x19]
+				} else {
+					if { [image width temp_smiley] > 50 || [image height temp_smiley] > 50 } {
+						#MSN can't show static smileys which are bigger than 50x50 so we resize it
+						set file [convert_image_plus [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] smileys 50x50]
+					} else {
+						#The smiley has size between 19x19 and 50x50 and user doesn't want to resize it so we just convert it to PNG
+						set filetail_noext [filenoext [file tail "$new_custom_cfg(file)"]]
+						set destfile [file join $HOME smileys $filetail_noext]
+						::picture::Convert [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] "${destfile}.png"
+						set file "${destfile}.png"
+					}
+				}
+			} else {
+				#The file is good so we just convert it to PNG
+				set filetail_noext [filenoext [file tail "$new_custom_cfg(file)"]]
+				set destfile [file join $HOME smileys $filetail_noext]
+				::picture::Convert [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] "${destfile}.png"
+				set file "${destfile}.png"
+			}
+			if { ![file exists $file] } { set file "" }
+		} else {
+			#We convert animated smiley to animated gif even if we can just load animated gif and save to animated gif
+			#Don't care of extension : as the smiley is animated TkCximage will save to GIF format
+			set filetail_noext [filenoext [file tail "$new_custom_cfg(file)"]]
+			set destfile [file join $HOME smileys $filetail_noext]
+			::picture::Convert [::skin::GetSkinFile smileys "$new_custom_cfg(file)"] "${destfile}.png"
+			set file "${destfile}.png"
+			if { ![file exists $file] } { set file "" }
+		}
+		
 		if { $file == "" } {
-			msg_box "[trans installconvert]"
 			return -1
 		}
 		
-		set emotion(file) "[filenoext $file].gif"
+		set emotion(file) $file
 		set emotion(name) $name
 		
 		#Create a list of symbols
@@ -747,28 +961,48 @@ namespace eval ::smiley {
 			}
 		}
 		
-		foreach element [list casesensitive animated] {
-			if { $new_custom_cfg($element) == 1} {
-				set emotion($element) 1
-			} else {
-				if { [info exist emotion($element)] } {unset emotion($element)}
-			}
-		}
+		#foreach element [list casesensitive animated] {
+		#	if { $new_custom_cfg($element) == 1} {
+		#		set emotion($element) 1
+		#	} else {
+		#		if { [info exist emotion($element)] } {unset emotion($element)}
+		#	}
+		#}
 		
-		set emotion(image_name) [image create photo -file $emotion(file) -format gif]
+		if { $new_custom_cfg(casesensitive) == 1} {
+			set emotion(casesensitive) 1
+		} else {
+			if { [info exist emotion(casesensitive)] } {unset emotion(casesensitive)}
+		} 
+		
+		
+		
+		set emotion(image_name) [image create photo -file $emotion(file) -format cximage]
 		set custom_emotions($name) [array get emotion]
-		if { $edit == 0} {
-			lappend [::config::getVar customsmileys] $name
-		}
 
 		#load_smileys
 		#::skin::reloadSkinSettings [::config::getGlobalKey skin]
 		if { [winfo exists .smile_selector]} {destroy .smile_selector}
+
+		#After modifying, clear sortedemotions, could need sorting again
+		variable sortedemotions
+		if {[info exists sortedemotions]} { unset sortedemotions }
 		
+				
 		#Immediately save settings.xml
 		save_config
 	}
 	
+	proc addSmileyFromTW { file } {
+		global new_custom_cfg
+		if { [winfo exists .new_custom] } {
+			raise .new_custom
+			return
+		}
+		set new_custom_cfg(file) [::skin::GetSkinFile smileys "cache/${file}.png"]
+		newCustomEmoticonGUI
+	}
+	
 			
 	#///////////////////////////////////////////////////////////////////////////////
 	# proc ValueForSmiley { emotion var } 
@@ -811,6 +1045,10 @@ namespace eval ::smiley {
 	# for example <:o) (party) may be considered as a :o smiley between < and ) ... 
 	proc CompareSmileyLength { a b } {
 	
+	#Get just the symbol (first element), not the type
+	set a [lindex $a 0]
+	set b [lindex $b 0]
+	
 	if { [string length $a] > [string length $b] } {
 		return -1
 	} elseif { [string length $a] < [string length $b] } {
@@ -841,7 +1079,7 @@ proc is_true { data } {
 
 
 proc custom_smile_subst { chatid tw {textbegin "0.0"} {end "end"} } {
-    upvar #0 ${chatid}_smileys emotions
+    upvar #0 [string map {: _} ${chatid} ]_smileys emotions
 
     if { ![info exists emotions] } { return }
 
@@ -850,7 +1088,9 @@ proc custom_smile_subst { chatid tw {textbegin "0.0"} {end "end"} } {
 } 
 
 proc custom_smile_subst2 { chatid tw textbegin end } { 
-    upvar #0 ${chatid}_smileys emotions
+    upvar #0 [string map {: _} ${chatid} ]_smileys emotions
+
+    set scrolling [::ChatWindow::getScrolling $tw]
 
     if { ![info exists emotions] } { return }
 
@@ -875,19 +1115,32 @@ proc custom_smile_subst2 { chatid tw textbegin end } {
 
 	    $tw tag configure smiley -elide true
 	    $tw tag add smiley $pos $endpos
+	    
+	    set twTag "custom_smiley_$file"
+	    set copyMenu "${tw}.custom_smiley_$file"
+	    if { ![winfo exists $copyMenu] } {
+		menu $copyMenu -tearoff 0 -type normal
+		$copyMenu add command -label [trans emoticon_steal] -command "::smiley::addSmileyFromTW {$file}"
+		$tw tag bind $twTag <Enter> "$tw configure -cursor hand2"
+		$tw tag bind $twTag <Leave> "$tw configure -cursor xterm"
+		$tw tag bind $twTag <<Button1>> "tk_popup $copyMenu %X %Y"
+	    }
 
-	    $tw image create $endpos -image custom_smiley_$file -pady 0 -padx 0
+	    set smileyIdx [$tw image create $endpos -image "custom_smiley_$file" -padx 0 -pady 0]
+	    $tw tag add $twTag $smileyIdx
 	    $tw tag remove smiley $endpos
 	    
 	}
     }
 
     unset emotions
+    
+    if { $scrolling } { ::ChatWindow::Scroll $tw }
 }
 
 #Called from the protocol layer to parse a x-mms-emoticon message
 proc parse_x_mms_emoticon { data chatid } {
-    upvar #0 ${chatid}_smileys smile
+    upvar #0 [string map {: _} ${chatid} ]_smileys smile
 
 
     if { [::config::getKey getdisppic] != 1 } { return }
@@ -895,11 +1148,11 @@ proc parse_x_mms_emoticon { data chatid } {
     set start 0
     while { $start < [string length $data]} {
 	set end [string first "	" $data $start]
-	set symbol [string range $data $start [expr $end - 1]]
-	set start [expr $end + 1]
+	set symbol [encoding convertfrom identity [string range $data $start [expr {$end - 1}]]]
+	set start [expr {$end + 1}]
 	set end [string first "	" $data $start]
-	set msnobj [string range $data $start [expr $end - 1]]
-	set start [expr $end + 1]
+	set msnobj [string range $data $start [expr {$end - 1}]]
+	set start [expr {$end + 1}]
 
 	set smile($symbol) "$msnobj"
     }
@@ -915,21 +1168,64 @@ proc process_custom_smileys_SB { txt } {
 	set txt2 [string toupper $txt]
 
 	#Try to find used smileys in the message	
-	foreach name [::config::getKey customsmileys] {
+	foreach name [array names custom_emotions] {
+	
+		if { ![info exists custom_emotions($name)] } {
+			status_log "process_custom_smileys_SB: Custom smiley $name doesn't exist in custom_emotions array!!\n" red
+			continue
+		}
 		
 		array set emotion $custom_emotions($name)
 		foreach symbol $emotion(text) {
 			set symbol2 [string toupper $symbol]
 		
 			set file $emotion(file)
+			if { ! [ info exists emotion(animated) ] || ! [ is_true $emotion(animated) ] } {
+				if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)] } {
+					if {  [string first $symbol $txt] != -1 } {
+						set msg "$msg$symbol	[create_msnobj [::config::getKey login] 2 [::skin::GetSkinFile smileys [filenoext $file].png]]	"
+					}
+				} else {
+					if {  [string first $symbol2 $txt2] != -1 } {
+						set msg "$msg$symbol	[create_msnobj [::config::getKey login] 2 [::skin::GetSkinFile smileys [filenoext $file].png]]	"
+					}
+				}
+			}
+		}
+	}
+	
+	return $msg
+}
+
+proc process_custom_animated_smileys_SB { txt } {
+	global custom_emotions
+	
+	set msg ""
+	
+	set txt2 [string toupper $txt]
+
+	#Try to find used smileys in the message	
+	foreach name [array names custom_emotions] {
+	
+		if { ![info exists custom_emotions($name)] } {
+			status_log "process_custom_smileys_SB: Custom smiley $name doesn't exist in custom_emotions array!!\n" red
+			continue
+		}
+		
+		array set emotion $custom_emotions($name)
+		foreach symbol $emotion(text) {
+			set symbol2 [string toupper $symbol]
 		
-			if { [info exists emotion(casesensitive] && [is_true $emotion(casesensitive)]} {
-				if {  [string first $symbol $txt] != -1 } {
-					set msg "$msg$symbol	[create_msnobj [::config::getKey login] 2 [GetSkinFile smileys [filenoext $file].png]]	"
-				}
-			} else {
-				if {  [string first $symbol2 $txt2] != -1 } {
-					set msg "$msg$symbol	[create_msnobj [::config::getKey login] 2 [GetSkinFile smileys [filenoext $file].png]]	"
+			set file $emotion(file)
+			if { [ info exists emotion(animated) ] && [ is_true $emotion(animated) ] } {
+				if { [info exists emotion(casesensitive)] && [is_true $emotion(casesensitive)] } {
+					if {  [string first $symbol $txt] != -1 } {
+						set msg "$msg$symbol	[create_msnobj [::config::getKey login] 2 [::skin::GetSkinFile smileys [filenoext $file].png]]	"
+					}
+				} else {
+					if {  [string first $symbol2 $txt2] != -1 } {
+						set msg "$msg$symbol	[create_msnobj [::config::getKey login] 2 [::skin::GetSkinFile smileys [filenoext $file].png]]	"
+					}
 				}
 			}
 		}
