@@ -142,7 +142,11 @@ namespace eval sxml {
 	 #Added by Alvaro Iradier. Use this instead of putting directly to the file, to
 	 #replace special characters
 	 proc xmlreplace {string} {
-	 	return [string map { "<" "&lt;" "&" "&amp;" "\"" "&quot;" "'" "&apos;"} $string]
+	 	return [string map { "<" "&lt;" ">" "&gt;" "&" "&amp;" "\"" "&quot;" "'" "&apos;"} $string]
+	 }
+
+	 proc replacexml {string} {
+	 	return [string map { "&lt;" "<" "&gt;" ">" "&amp;" "&" "&quot;" "\"" "&apos;" "'" } $string]
 	 }
 
     proc init {file} {
@@ -379,7 +383,11 @@ namespace eval sxml {
             if { [string first "&lt;" $tcline] == 0 } {
                 incr c 4
                 return {<}
-            } 
+            }
+            if { [string first "&gt;" $tcline] == 0 } {
+                incr c 4
+                return {>}
+            }
             if { [string first "&quot;" $tcline] == 0 } {
                 incr c 6
                 return \"
@@ -868,3 +876,131 @@ proc parse {id} {
 }
 
 }
+
+proc xml2list xml {
+	regsub -all {>\s*<} [string trim $xml " \n\t<>"] "\} \{" xml
+	set xml [string map {> "\} \{#text \{" < "\}\} \{"}  $xml]
+	
+	set res ""   ;# string to collect the result
+	set stack {} ;# track open tags
+	set rest {}
+	foreach item "{$xml}" {
+		switch -regexp -- $item {
+			^# {append res "{[lrange $item 0 end]} " ; #text item}
+			^/ {
+				regexp {/(.+)} $item -> tagname ;# end tag
+				set expected [lindex $stack end]
+				if {$tagname!=$expected} {error "$item != $expected"}
+				set stack [lrange $stack 0 end-1]
+				append res "\}\} "
+			}
+			/$ { # singleton - start and end in one <> group
+				regexp {([^ ]+)( (.+))?/$} $item -> tagname - rest
+				set rest [lrange [string map {= " "} $rest] 0 end]
+				append res "{$tagname [list $rest] {}} "
+			}
+			default {
+				set tagname [lindex $item 0] ;# start tag
+				set rest [lrange [string map {= " "} $item] 1 end]
+				lappend stack $tagname
+				append res "\{$tagname [list $rest] \{"
+			}
+		}
+		if {[llength $rest]%2} {error "att's not paired: $rest"}
+	}
+	if [llength $stack] {error "unresolved: $stack"}
+	string map {"\} \}" "\}\}"} [lindex $res 0]
+}
+
+proc list2xml list {
+	switch -- [llength $list] {
+		2 {lindex $list 1}
+		3 {
+			foreach {tag attributes children} $list break
+			set res <$tag
+			foreach {name value} $attributes {
+				append res " $name=\"$value\""
+			}
+			if [llength $children] {
+				append res >
+				foreach child $children {
+					append res [list2xml $child]
+				}
+				append res </$tag>
+			} else {append res />}
+		}
+		default {error "could not parse $list"}
+	}
+}
+
+proc GetXmlEntry { list find {stack ""}} {
+
+	set current_stack $stack
+	foreach { entry attributes content} $list {
+		set current_stack "$stack:$entry"
+		if {$current_stack == $find || $current_stack == ":$find" } {
+			#status_log "Found it in $current_stack\n" red
+			foreach subkey $content {
+				set key [lindex $subkey 0]
+				set value [lindex $subkey 1]
+				if {$key == "#text" } { 
+					status_log "Found value : $value" blue
+					return $value 
+				}
+			}
+			return ""
+		} else {
+			if {[string first $current_stack $find] == -1 &&
+			    [string first $current_stack ":$find"] == -1 } {
+				#status_log "$find not in $current_stack" red
+				continue
+			} else { 
+				#status_log "$find is in a subkey of $current_stack\n" red
+				foreach subkey $content {
+					set result [GetXmlEntry $subkey $find $current_stack]
+					if { $result != "" } {
+						return $result
+					}
+				}
+			}
+		}	
+	}
+	
+	return ""
+	
+}
+
+
+proc GetXmlAttribute { list find attribute_name {stack ""}} {
+
+	set current_stack $stack
+	foreach { entry attributes content} $list {
+		set current_stack "$stack:$entry"
+		if {$current_stack == $find || $current_stack == ":$find" } {
+			#status_log "Found it in $current_stack\n" blue
+			array set attributes_arr $attributes
+			if { [info exists attributes_arr($attribute_name)] } {
+				return [set attributes_arr($attribute_name)]
+			} else {
+				return ""
+			}
+		} else {
+			if {[string first $current_stack $find] == -1 &&
+			    [string first $current_stack ":$find"] == -1 } {
+				#status_log "$find not in $current_stack" red
+				continue
+			} else { 
+				#status_log "$find is in a subkey of $current_stack\n" red
+				foreach subkey $content {
+					set result [GetXmlAttribute $subkey $find $attribute_name $current_stack]
+					if { $result != "" } {
+						return $result
+					}
+				}
+			}
+		}	
+	}
+	
+	return ""
+	
+}
\ No newline at end of file
